# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AccountCreatedEvent import AccountCreatedEvent as AccountCreatedEvent
from .AccountRemovedEvent import AccountRemovedEvent as AccountRemovedEvent
from .AccountUpdatedEvent import AccountUpdatedEvent as AccountUpdatedEvent
from .AdminPasswordNotChangedEvent import AdminPasswordNotChangedEvent as AdminPasswordNotChangedEvent
from .AlarmAcknowledgedEvent import AlarmAcknowledgedEvent as AlarmAcknowledgedEvent
from .AlarmActionTriggeredEvent import AlarmActionTriggeredEvent as AlarmActionTriggeredEvent
from .AlarmClearedEvent import AlarmClearedEvent as AlarmClearedEvent
from .AlarmCreatedEvent import AlarmCreatedEvent as AlarmCreatedEvent
from .AlarmEmailCompletedEvent import AlarmEmailCompletedEvent as AlarmEmailCompletedEvent
from .AlarmEmailFailedEvent import AlarmEmailFailedEvent as AlarmEmailFailedEvent
from .AlarmEvent import AlarmEvent as AlarmEvent
from .AlarmEventArgument import AlarmEventArgument as AlarmEventArgument
from .AlarmReconfiguredEvent import AlarmReconfiguredEvent as AlarmReconfiguredEvent
from .AlarmRemovedEvent import AlarmRemovedEvent as AlarmRemovedEvent
from .AlarmScriptCompleteEvent import AlarmScriptCompleteEvent as AlarmScriptCompleteEvent
from .AlarmScriptFailedEvent import AlarmScriptFailedEvent as AlarmScriptFailedEvent
from .AlarmSnmpCompletedEvent import AlarmSnmpCompletedEvent as AlarmSnmpCompletedEvent
from .AlarmSnmpFailedEvent import AlarmSnmpFailedEvent as AlarmSnmpFailedEvent
from .AlarmStatusChangedEvent import AlarmStatusChangedEvent as AlarmStatusChangedEvent
from .AllVirtualMachinesLicensedEvent import AllVirtualMachinesLicensedEvent as AllVirtualMachinesLicensedEvent
from .AlreadyAuthenticatedSessionEvent import AlreadyAuthenticatedSessionEvent as AlreadyAuthenticatedSessionEvent
from .AuthorizationEvent import AuthorizationEvent as AuthorizationEvent
from .BadUsernameSessionEvent import BadUsernameSessionEvent as BadUsernameSessionEvent
from .CanceledHostOperationEvent import CanceledHostOperationEvent as CanceledHostOperationEvent
from .ChangesInfoEventArgument import ChangesInfoEventArgument as ChangesInfoEventArgument
from .ClusterComplianceCheckedEvent import ClusterComplianceCheckedEvent as ClusterComplianceCheckedEvent
from .ClusterCreatedEvent import ClusterCreatedEvent as ClusterCreatedEvent
from .ClusterDestroyedEvent import ClusterDestroyedEvent as ClusterDestroyedEvent
from .ClusterEvent import ClusterEvent as ClusterEvent
from .ClusterOvercommittedEvent import ClusterOvercommittedEvent as ClusterOvercommittedEvent
from .ClusterReconfiguredEvent import ClusterReconfiguredEvent as ClusterReconfiguredEvent
from .ClusterStatusChangedEvent import ClusterStatusChangedEvent as ClusterStatusChangedEvent
from .ComputeResourceEventArgument import ComputeResourceEventArgument as ComputeResourceEventArgument
from .CustomFieldDefAddedEvent import CustomFieldDefAddedEvent as CustomFieldDefAddedEvent
from .CustomFieldDefEvent import CustomFieldDefEvent as CustomFieldDefEvent
from .CustomFieldDefRemovedEvent import CustomFieldDefRemovedEvent as CustomFieldDefRemovedEvent
from .CustomFieldDefRenamedEvent import CustomFieldDefRenamedEvent as CustomFieldDefRenamedEvent
from .CustomFieldEvent import CustomFieldEvent as CustomFieldEvent
from .CustomFieldValueChangedEvent import CustomFieldValueChangedEvent as CustomFieldValueChangedEvent
from .CustomizationEvent import CustomizationEvent as CustomizationEvent
from .CustomizationFailed import CustomizationFailed as CustomizationFailed
from .CustomizationLinuxIdentityFailed import CustomizationLinuxIdentityFailed as CustomizationLinuxIdentityFailed
from .CustomizationNetworkSetupFailed import CustomizationNetworkSetupFailed as CustomizationNetworkSetupFailed
from .CustomizationStartedEvent import CustomizationStartedEvent as CustomizationStartedEvent
from .CustomizationSucceeded import CustomizationSucceeded as CustomizationSucceeded
from .CustomizationSysprepFailed import CustomizationSysprepFailed as CustomizationSysprepFailed
from .CustomizationUnknownFailure import CustomizationUnknownFailure as CustomizationUnknownFailure
from .DVPortgroupCreatedEvent import DVPortgroupCreatedEvent as DVPortgroupCreatedEvent
from .DVPortgroupDestroyedEvent import DVPortgroupDestroyedEvent as DVPortgroupDestroyedEvent
from .DVPortgroupEvent import DVPortgroupEvent as DVPortgroupEvent
from .DVPortgroupReconfiguredEvent import DVPortgroupReconfiguredEvent as DVPortgroupReconfiguredEvent
from .DVPortgroupRenamedEvent import DVPortgroupRenamedEvent as DVPortgroupRenamedEvent
from .DasAdmissionControlDisabledEvent import DasAdmissionControlDisabledEvent as DasAdmissionControlDisabledEvent
from .DasAdmissionControlEnabledEvent import DasAdmissionControlEnabledEvent as DasAdmissionControlEnabledEvent
from .DasAgentFoundEvent import DasAgentFoundEvent as DasAgentFoundEvent
from .DasAgentUnavailableEvent import DasAgentUnavailableEvent as DasAgentUnavailableEvent
from .DasClusterIsolatedEvent import DasClusterIsolatedEvent as DasClusterIsolatedEvent
from .DasDisabledEvent import DasDisabledEvent as DasDisabledEvent
from .DasEnabledEvent import DasEnabledEvent as DasEnabledEvent
from .DasHostFailedEvent import DasHostFailedEvent as DasHostFailedEvent
from .DasHostIsolatedEvent import DasHostIsolatedEvent as DasHostIsolatedEvent
from .DatacenterCreatedEvent import DatacenterCreatedEvent as DatacenterCreatedEvent
from .DatacenterEvent import DatacenterEvent as DatacenterEvent
from .DatacenterEventArgument import DatacenterEventArgument as DatacenterEventArgument
from .DatacenterRenamedEvent import DatacenterRenamedEvent as DatacenterRenamedEvent
from .DatastoreCapacityIncreasedEvent import DatastoreCapacityIncreasedEvent as DatastoreCapacityIncreasedEvent
from .DatastoreDestroyedEvent import DatastoreDestroyedEvent as DatastoreDestroyedEvent
from .DatastoreDiscoveredEvent import DatastoreDiscoveredEvent as DatastoreDiscoveredEvent
from .DatastoreDuplicatedEvent import DatastoreDuplicatedEvent as DatastoreDuplicatedEvent
from .DatastoreEvent import DatastoreEvent as DatastoreEvent
from .DatastoreEventArgument import DatastoreEventArgument as DatastoreEventArgument
from .DatastoreFileCopiedEvent import DatastoreFileCopiedEvent as DatastoreFileCopiedEvent
from .DatastoreFileDeletedEvent import DatastoreFileDeletedEvent as DatastoreFileDeletedEvent
from .DatastoreFileEvent import DatastoreFileEvent as DatastoreFileEvent
from .DatastoreFileMovedEvent import DatastoreFileMovedEvent as DatastoreFileMovedEvent
from .DatastoreIORMReconfiguredEvent import DatastoreIORMReconfiguredEvent as DatastoreIORMReconfiguredEvent
from .DatastorePrincipalConfigured import DatastorePrincipalConfigured as DatastorePrincipalConfigured
from .DatastoreRemovedOnHostEvent import DatastoreRemovedOnHostEvent as DatastoreRemovedOnHostEvent
from .DatastoreRenamedEvent import DatastoreRenamedEvent as DatastoreRenamedEvent
from .DatastoreRenamedOnHostEvent import DatastoreRenamedOnHostEvent as DatastoreRenamedOnHostEvent
from .DrsDisabledEvent import DrsDisabledEvent as DrsDisabledEvent
from .DrsEnabledEvent import DrsEnabledEvent as DrsEnabledEvent
from .DrsEnteredStandbyModeEvent import DrsEnteredStandbyModeEvent as DrsEnteredStandbyModeEvent
from .DrsEnteringStandbyModeEvent import DrsEnteringStandbyModeEvent as DrsEnteringStandbyModeEvent
from .DrsExitStandbyModeFailedEvent import DrsExitStandbyModeFailedEvent as DrsExitStandbyModeFailedEvent
from .DrsExitedStandbyModeEvent import DrsExitedStandbyModeEvent as DrsExitedStandbyModeEvent
from .DrsExitingStandbyModeEvent import DrsExitingStandbyModeEvent as DrsExitingStandbyModeEvent
from .DrsInvocationFailedEvent import DrsInvocationFailedEvent as DrsInvocationFailedEvent
from .DrsRecoveredFromFailureEvent import DrsRecoveredFromFailureEvent as DrsRecoveredFromFailureEvent
from .DrsResourceConfigureFailedEvent import DrsResourceConfigureFailedEvent as DrsResourceConfigureFailedEvent
from .DrsResourceConfigureSyncedEvent import DrsResourceConfigureSyncedEvent as DrsResourceConfigureSyncedEvent
from .DrsRuleComplianceEvent import DrsRuleComplianceEvent as DrsRuleComplianceEvent
from .DrsRuleViolationEvent import DrsRuleViolationEvent as DrsRuleViolationEvent
from .DrsSoftRuleViolationEvent import DrsSoftRuleViolationEvent as DrsSoftRuleViolationEvent
from .DrsVmMigratedEvent import DrsVmMigratedEvent as DrsVmMigratedEvent
from .DrsVmPoweredOnEvent import DrsVmPoweredOnEvent as DrsVmPoweredOnEvent
from .DuplicateIpDetectedEvent import DuplicateIpDetectedEvent as DuplicateIpDetectedEvent
from .DvpgImportEvent import DvpgImportEvent as DvpgImportEvent
from .DvpgRestoreEvent import DvpgRestoreEvent as DvpgRestoreEvent
from .DvsCreatedEvent import DvsCreatedEvent as DvsCreatedEvent
from .DvsDestroyedEvent import DvsDestroyedEvent as DvsDestroyedEvent
from .DvsEvent import DvsEvent as DvsEvent
from .DvsEventArgument import DvsEventArgument as DvsEventArgument
from .DvsHealthStatusChangeEvent import DvsHealthStatusChangeEvent as DvsHealthStatusChangeEvent
from .DvsHostBackInSyncEvent import DvsHostBackInSyncEvent as DvsHostBackInSyncEvent
from .DvsHostJoinedEvent import DvsHostJoinedEvent as DvsHostJoinedEvent
from .DvsHostLeftEvent import DvsHostLeftEvent as DvsHostLeftEvent
from .DvsHostStatusUpdated import DvsHostStatusUpdated as DvsHostStatusUpdated
from .DvsHostWentOutOfSyncEvent import DvsHostWentOutOfSyncEvent as DvsHostWentOutOfSyncEvent
from .DvsImportEvent import DvsImportEvent as DvsImportEvent
from .DvsMergedEvent import DvsMergedEvent as DvsMergedEvent
from .DvsOutOfSyncHostArgument import DvsOutOfSyncHostArgument as DvsOutOfSyncHostArgument
from .DvsPortBlockedEvent import DvsPortBlockedEvent as DvsPortBlockedEvent
from .DvsPortConnectedEvent import DvsPortConnectedEvent as DvsPortConnectedEvent
from .DvsPortCreatedEvent import DvsPortCreatedEvent as DvsPortCreatedEvent
from .DvsPortDeletedEvent import DvsPortDeletedEvent as DvsPortDeletedEvent
from .DvsPortDisconnectedEvent import DvsPortDisconnectedEvent as DvsPortDisconnectedEvent
from .DvsPortEnteredPassthruEvent import DvsPortEnteredPassthruEvent as DvsPortEnteredPassthruEvent
from .DvsPortExitedPassthruEvent import DvsPortExitedPassthruEvent as DvsPortExitedPassthruEvent
from .DvsPortJoinPortgroupEvent import DvsPortJoinPortgroupEvent as DvsPortJoinPortgroupEvent
from .DvsPortLeavePortgroupEvent import DvsPortLeavePortgroupEvent as DvsPortLeavePortgroupEvent
from .DvsPortLinkDownEvent import DvsPortLinkDownEvent as DvsPortLinkDownEvent
from .DvsPortLinkUpEvent import DvsPortLinkUpEvent as DvsPortLinkUpEvent
from .DvsPortReconfiguredEvent import DvsPortReconfiguredEvent as DvsPortReconfiguredEvent
from .DvsPortRuntimeChangeEvent import DvsPortRuntimeChangeEvent as DvsPortRuntimeChangeEvent
from .DvsPortUnblockedEvent import DvsPortUnblockedEvent as DvsPortUnblockedEvent
from .DvsPortVendorSpecificStateChangeEvent import DvsPortVendorSpecificStateChangeEvent as DvsPortVendorSpecificStateChangeEvent
from .DvsReconfiguredEvent import DvsReconfiguredEvent as DvsReconfiguredEvent
from .DvsRenamedEvent import DvsRenamedEvent as DvsRenamedEvent
from .DvsRestoreEvent import DvsRestoreEvent as DvsRestoreEvent
from .DvsUpgradeAvailableEvent import DvsUpgradeAvailableEvent as DvsUpgradeAvailableEvent
from .DvsUpgradeInProgressEvent import DvsUpgradeInProgressEvent as DvsUpgradeInProgressEvent
from .DvsUpgradeRejectedEvent import DvsUpgradeRejectedEvent as DvsUpgradeRejectedEvent
from .DvsUpgradedEvent import DvsUpgradedEvent as DvsUpgradedEvent
from .EnteredMaintenanceModeEvent import EnteredMaintenanceModeEvent as EnteredMaintenanceModeEvent
from .EnteredStandbyModeEvent import EnteredStandbyModeEvent as EnteredStandbyModeEvent
from .EnteringMaintenanceModeEvent import EnteringMaintenanceModeEvent as EnteringMaintenanceModeEvent
from .EnteringStandbyModeEvent import EnteringStandbyModeEvent as EnteringStandbyModeEvent
from .EntityEventArgument import EntityEventArgument as EntityEventArgument
from .ErrorUpgradeEvent import ErrorUpgradeEvent as ErrorUpgradeEvent
from .Event import Event as Event
from .EventArgument import EventArgument as EventArgument
from .EventDescription import EventDescription as EventDescription
from .EventEx import EventEx as EventEx
from .EventFilterSpec import EventFilterSpec as EventFilterSpec
from .EventHistoryCollector import EventHistoryCollector as EventHistoryCollector
from .EventManager import EventManager as EventManager
from .ExitMaintenanceModeEvent import ExitMaintenanceModeEvent as ExitMaintenanceModeEvent
from .ExitStandbyModeFailedEvent import ExitStandbyModeFailedEvent as ExitStandbyModeFailedEvent
from .ExitedStandbyModeEvent import ExitedStandbyModeEvent as ExitedStandbyModeEvent
from .ExitingStandbyModeEvent import ExitingStandbyModeEvent as ExitingStandbyModeEvent
from .ExtendedEvent import ExtendedEvent as ExtendedEvent
from .FailoverLevelRestored import FailoverLevelRestored as FailoverLevelRestored
from .FolderEventArgument import FolderEventArgument as FolderEventArgument
from .GeneralEvent import GeneralEvent as GeneralEvent
from .GeneralHostErrorEvent import GeneralHostErrorEvent as GeneralHostErrorEvent
from .GeneralHostInfoEvent import GeneralHostInfoEvent as GeneralHostInfoEvent
from .GeneralHostWarningEvent import GeneralHostWarningEvent as GeneralHostWarningEvent
from .GeneralUserEvent import GeneralUserEvent as GeneralUserEvent
from .GeneralVmErrorEvent import GeneralVmErrorEvent as GeneralVmErrorEvent
from .GeneralVmInfoEvent import GeneralVmInfoEvent as GeneralVmInfoEvent
from .GeneralVmWarningEvent import GeneralVmWarningEvent as GeneralVmWarningEvent
from .GhostDvsProxySwitchDetectedEvent import GhostDvsProxySwitchDetectedEvent as GhostDvsProxySwitchDetectedEvent
from .GhostDvsProxySwitchRemovedEvent import GhostDvsProxySwitchRemovedEvent as GhostDvsProxySwitchRemovedEvent
from .GlobalMessageChangedEvent import GlobalMessageChangedEvent as GlobalMessageChangedEvent
from .HealthStatusChangedEvent import HealthStatusChangedEvent as HealthStatusChangedEvent
from .HostAddFailedEvent import HostAddFailedEvent as HostAddFailedEvent
from .HostAddedEvent import HostAddedEvent as HostAddedEvent
from .HostAdminDisableEvent import HostAdminDisableEvent as HostAdminDisableEvent
from .HostAdminEnableEvent import HostAdminEnableEvent as HostAdminEnableEvent
from .HostCnxFailedAccountFailedEvent import HostCnxFailedAccountFailedEvent as HostCnxFailedAccountFailedEvent
from .HostCnxFailedAlreadyManagedEvent import HostCnxFailedAlreadyManagedEvent as HostCnxFailedAlreadyManagedEvent
from .HostCnxFailedBadCcagentEvent import HostCnxFailedBadCcagentEvent as HostCnxFailedBadCcagentEvent
from .HostCnxFailedBadUsernameEvent import HostCnxFailedBadUsernameEvent as HostCnxFailedBadUsernameEvent
from .HostCnxFailedBadVersionEvent import HostCnxFailedBadVersionEvent as HostCnxFailedBadVersionEvent
from .HostCnxFailedCcagentUpgradeEvent import HostCnxFailedCcagentUpgradeEvent as HostCnxFailedCcagentUpgradeEvent
from .HostCnxFailedEvent import HostCnxFailedEvent as HostCnxFailedEvent
from .HostCnxFailedNetworkErrorEvent import HostCnxFailedNetworkErrorEvent as HostCnxFailedNetworkErrorEvent
from .HostCnxFailedNoAccessEvent import HostCnxFailedNoAccessEvent as HostCnxFailedNoAccessEvent
from .HostCnxFailedNoConnectionEvent import HostCnxFailedNoConnectionEvent as HostCnxFailedNoConnectionEvent
from .HostCnxFailedNoLicenseEvent import HostCnxFailedNoLicenseEvent as HostCnxFailedNoLicenseEvent
from .HostCnxFailedNotFoundEvent import HostCnxFailedNotFoundEvent as HostCnxFailedNotFoundEvent
from .HostCnxFailedTimeoutEvent import HostCnxFailedTimeoutEvent as HostCnxFailedTimeoutEvent
from .HostComplianceCheckedEvent import HostComplianceCheckedEvent as HostComplianceCheckedEvent
from .HostCompliantEvent import HostCompliantEvent as HostCompliantEvent
from .HostConfigAppliedEvent import HostConfigAppliedEvent as HostConfigAppliedEvent
from .HostConnectedEvent import HostConnectedEvent as HostConnectedEvent
from .HostConnectionLostEvent import HostConnectionLostEvent as HostConnectionLostEvent
from .HostDasDisabledEvent import HostDasDisabledEvent as HostDasDisabledEvent
from .HostDasDisablingEvent import HostDasDisablingEvent as HostDasDisablingEvent
from .HostDasEnabledEvent import HostDasEnabledEvent as HostDasEnabledEvent
from .HostDasEnablingEvent import HostDasEnablingEvent as HostDasEnablingEvent
from .HostDasErrorEvent import HostDasErrorEvent as HostDasErrorEvent
from .HostDasEvent import HostDasEvent as HostDasEvent
from .HostDasOkEvent import HostDasOkEvent as HostDasOkEvent
from .HostDisconnectedEvent import HostDisconnectedEvent as HostDisconnectedEvent
from .HostEnableAdminFailedEvent import HostEnableAdminFailedEvent as HostEnableAdminFailedEvent
from .HostEvent import HostEvent as HostEvent
from .HostEventArgument import HostEventArgument as HostEventArgument
from .HostExtraNetworksEvent import HostExtraNetworksEvent as HostExtraNetworksEvent
from .HostGetShortNameFailedEvent import HostGetShortNameFailedEvent as HostGetShortNameFailedEvent
from .HostInAuditModeEvent import HostInAuditModeEvent as HostInAuditModeEvent
from .HostInventoryFullEvent import HostInventoryFullEvent as HostInventoryFullEvent
from .HostInventoryUnreadableEvent import HostInventoryUnreadableEvent as HostInventoryUnreadableEvent
from .HostIpChangedEvent import HostIpChangedEvent as HostIpChangedEvent
from .HostIpInconsistentEvent import HostIpInconsistentEvent as HostIpInconsistentEvent
from .HostIpToShortNameFailedEvent import HostIpToShortNameFailedEvent as HostIpToShortNameFailedEvent
from .HostIsolationIpPingFailedEvent import HostIsolationIpPingFailedEvent as HostIsolationIpPingFailedEvent
from .HostLicenseExpiredEvent import HostLicenseExpiredEvent as HostLicenseExpiredEvent
from .HostLocalPortCreatedEvent import HostLocalPortCreatedEvent as HostLocalPortCreatedEvent
from .HostMissingNetworksEvent import HostMissingNetworksEvent as HostMissingNetworksEvent
from .HostMonitoringStateChangedEvent import HostMonitoringStateChangedEvent as HostMonitoringStateChangedEvent
from .HostNoAvailableNetworksEvent import HostNoAvailableNetworksEvent as HostNoAvailableNetworksEvent
from .HostNoHAEnabledPortGroupsEvent import HostNoHAEnabledPortGroupsEvent as HostNoHAEnabledPortGroupsEvent
from .HostNoRedundantManagementNetworkEvent import HostNoRedundantManagementNetworkEvent as HostNoRedundantManagementNetworkEvent
from .HostNonCompliantEvent import HostNonCompliantEvent as HostNonCompliantEvent
from .HostNotInClusterEvent import HostNotInClusterEvent as HostNotInClusterEvent
from .HostOvercommittedEvent import HostOvercommittedEvent as HostOvercommittedEvent
from .HostPrimaryAgentNotShortNameEvent import HostPrimaryAgentNotShortNameEvent as HostPrimaryAgentNotShortNameEvent
from .HostProfileAppliedEvent import HostProfileAppliedEvent as HostProfileAppliedEvent
from .HostReconnectionFailedEvent import HostReconnectionFailedEvent as HostReconnectionFailedEvent
from .HostRemovedEvent import HostRemovedEvent as HostRemovedEvent
from .HostShortNameInconsistentEvent import HostShortNameInconsistentEvent as HostShortNameInconsistentEvent
from .HostShortNameToIpFailedEvent import HostShortNameToIpFailedEvent as HostShortNameToIpFailedEvent
from .HostShutdownEvent import HostShutdownEvent as HostShutdownEvent
from .HostSpecificationChangedEvent import HostSpecificationChangedEvent as HostSpecificationChangedEvent
from .HostSpecificationRequireEvent import HostSpecificationRequireEvent as HostSpecificationRequireEvent
from .HostSpecificationUpdateEvent import HostSpecificationUpdateEvent as HostSpecificationUpdateEvent
from .HostStatusChangedEvent import HostStatusChangedEvent as HostStatusChangedEvent
from .HostSubSpecificationDeleteEvent import HostSubSpecificationDeleteEvent as HostSubSpecificationDeleteEvent
from .HostSubSpecificationUpdateEvent import HostSubSpecificationUpdateEvent as HostSubSpecificationUpdateEvent
from .HostSyncFailedEvent import HostSyncFailedEvent as HostSyncFailedEvent
from .HostUpgradeFailedEvent import HostUpgradeFailedEvent as HostUpgradeFailedEvent
from .HostUserWorldSwapNotEnabledEvent import HostUserWorldSwapNotEnabledEvent as HostUserWorldSwapNotEnabledEvent
from .HostVnicConnectedToCustomizedDVPortEvent import HostVnicConnectedToCustomizedDVPortEvent as HostVnicConnectedToCustomizedDVPortEvent
from .HostWwnChangedEvent import HostWwnChangedEvent as HostWwnChangedEvent
from .HostWwnConflictEvent import HostWwnConflictEvent as HostWwnConflictEvent
from .IncorrectHostInformationEvent import IncorrectHostInformationEvent as IncorrectHostInformationEvent
from .InfoUpgradeEvent import InfoUpgradeEvent as InfoUpgradeEvent
from .InsufficientFailoverResourcesEvent import InsufficientFailoverResourcesEvent as InsufficientFailoverResourcesEvent
from .InvalidEditionEvent import InvalidEditionEvent as InvalidEditionEvent
from .LicenseEvent import LicenseEvent as LicenseEvent
from .LicenseExpiredEvent import LicenseExpiredEvent as LicenseExpiredEvent
from .LicenseNonComplianceEvent import LicenseNonComplianceEvent as LicenseNonComplianceEvent
from .LicenseRestrictedEvent import LicenseRestrictedEvent as LicenseRestrictedEvent
from .LicenseServerAvailableEvent import LicenseServerAvailableEvent as LicenseServerAvailableEvent
from .LicenseServerUnavailableEvent import LicenseServerUnavailableEvent as LicenseServerUnavailableEvent
from .LocalDatastoreCreatedEvent import LocalDatastoreCreatedEvent as LocalDatastoreCreatedEvent
from .LocalTSMEnabledEvent import LocalTSMEnabledEvent as LocalTSMEnabledEvent
from .LockerMisconfiguredEvent import LockerMisconfiguredEvent as LockerMisconfiguredEvent
from .LockerReconfiguredEvent import LockerReconfiguredEvent as LockerReconfiguredEvent
from .ManagedEntityEventArgument import ManagedEntityEventArgument as ManagedEntityEventArgument
from .MigrationErrorEvent import MigrationErrorEvent as MigrationErrorEvent
from .MigrationEvent import MigrationEvent as MigrationEvent
from .MigrationHostErrorEvent import MigrationHostErrorEvent as MigrationHostErrorEvent
from .MigrationHostWarningEvent import MigrationHostWarningEvent as MigrationHostWarningEvent
from .MigrationResourceErrorEvent import MigrationResourceErrorEvent as MigrationResourceErrorEvent
from .MigrationResourceWarningEvent import MigrationResourceWarningEvent as MigrationResourceWarningEvent
from .MigrationWarningEvent import MigrationWarningEvent as MigrationWarningEvent
from .MtuMatchEvent import MtuMatchEvent as MtuMatchEvent
from .MtuMismatchEvent import MtuMismatchEvent as MtuMismatchEvent
from .NASDatastoreCreatedEvent import NASDatastoreCreatedEvent as NASDatastoreCreatedEvent
from .NetworkEventArgument import NetworkEventArgument as NetworkEventArgument
from .NetworkRollbackEvent import NetworkRollbackEvent as NetworkRollbackEvent
from .NoAccessUserEvent import NoAccessUserEvent as NoAccessUserEvent
from .NoDatastoresConfiguredEvent import NoDatastoresConfiguredEvent as NoDatastoresConfiguredEvent
from .NoLicenseEvent import NoLicenseEvent as NoLicenseEvent
from .NoMaintenanceModeDrsRecommendationForVM import NoMaintenanceModeDrsRecommendationForVM as NoMaintenanceModeDrsRecommendationForVM
from .NonVIWorkloadDetectedOnDatastoreEvent import NonVIWorkloadDetectedOnDatastoreEvent as NonVIWorkloadDetectedOnDatastoreEvent
from .NotEnoughResourcesToStartVmEvent import NotEnoughResourcesToStartVmEvent as NotEnoughResourcesToStartVmEvent
from .OutOfSyncDvsHost import OutOfSyncDvsHost as OutOfSyncDvsHost
from .PermissionAddedEvent import PermissionAddedEvent as PermissionAddedEvent
from .PermissionEvent import PermissionEvent as PermissionEvent
from .PermissionRemovedEvent import PermissionRemovedEvent as PermissionRemovedEvent
from .PermissionUpdatedEvent import PermissionUpdatedEvent as PermissionUpdatedEvent
from .ProfileAssociatedEvent import ProfileAssociatedEvent as ProfileAssociatedEvent
from .ProfileChangedEvent import ProfileChangedEvent as ProfileChangedEvent
from .ProfileCreatedEvent import ProfileCreatedEvent as ProfileCreatedEvent
from .ProfileDissociatedEvent import ProfileDissociatedEvent as ProfileDissociatedEvent
from .ProfileEvent import ProfileEvent as ProfileEvent
from .ProfileEventArgument import ProfileEventArgument as ProfileEventArgument
from .ProfileReferenceHostChangedEvent import ProfileReferenceHostChangedEvent as ProfileReferenceHostChangedEvent
from .ProfileRemovedEvent import ProfileRemovedEvent as ProfileRemovedEvent
from .RecoveryEvent import RecoveryEvent as RecoveryEvent
from .RemoteTSMEnabledEvent import RemoteTSMEnabledEvent as RemoteTSMEnabledEvent
from .ResourcePoolCreatedEvent import ResourcePoolCreatedEvent as ResourcePoolCreatedEvent
from .ResourcePoolDestroyedEvent import ResourcePoolDestroyedEvent as ResourcePoolDestroyedEvent
from .ResourcePoolEvent import ResourcePoolEvent as ResourcePoolEvent
from .ResourcePoolEventArgument import ResourcePoolEventArgument as ResourcePoolEventArgument
from .ResourcePoolMovedEvent import ResourcePoolMovedEvent as ResourcePoolMovedEvent
from .ResourcePoolReconfiguredEvent import ResourcePoolReconfiguredEvent as ResourcePoolReconfiguredEvent
from .ResourceViolatedEvent import ResourceViolatedEvent as ResourceViolatedEvent
from .RoleAddedEvent import RoleAddedEvent as RoleAddedEvent
from .RoleEvent import RoleEvent as RoleEvent
from .RoleEventArgument import RoleEventArgument as RoleEventArgument
from .RoleRemovedEvent import RoleRemovedEvent as RoleRemovedEvent
from .RoleUpdatedEvent import RoleUpdatedEvent as RoleUpdatedEvent
from .RollbackEvent import RollbackEvent as RollbackEvent
from .ScheduledTaskCompletedEvent import ScheduledTaskCompletedEvent as ScheduledTaskCompletedEvent
from .ScheduledTaskCreatedEvent import ScheduledTaskCreatedEvent as ScheduledTaskCreatedEvent
from .ScheduledTaskEmailCompletedEvent import ScheduledTaskEmailCompletedEvent as ScheduledTaskEmailCompletedEvent
from .ScheduledTaskEmailFailedEvent import ScheduledTaskEmailFailedEvent as ScheduledTaskEmailFailedEvent
from .ScheduledTaskEvent import ScheduledTaskEvent as ScheduledTaskEvent
from .ScheduledTaskEventArgument import ScheduledTaskEventArgument as ScheduledTaskEventArgument
from .ScheduledTaskFailedEvent import ScheduledTaskFailedEvent as ScheduledTaskFailedEvent
from .ScheduledTaskReconfiguredEvent import ScheduledTaskReconfiguredEvent as ScheduledTaskReconfiguredEvent
from .ScheduledTaskRemovedEvent import ScheduledTaskRemovedEvent as ScheduledTaskRemovedEvent
from .ScheduledTaskStartedEvent import ScheduledTaskStartedEvent as ScheduledTaskStartedEvent
from .ServerLicenseExpiredEvent import ServerLicenseExpiredEvent as ServerLicenseExpiredEvent
from .ServerStartedSessionEvent import ServerStartedSessionEvent as ServerStartedSessionEvent
from .SessionEvent import SessionEvent as SessionEvent
from .SessionTerminatedEvent import SessionTerminatedEvent as SessionTerminatedEvent
from .TaskEvent import TaskEvent as TaskEvent
from .TaskTimeoutEvent import TaskTimeoutEvent as TaskTimeoutEvent
from .TeamingMatchEvent import TeamingMatchEvent as TeamingMatchEvent
from .TeamingMisMatchEvent import TeamingMisMatchEvent as TeamingMisMatchEvent
from .TemplateBeingUpgradedEvent import TemplateBeingUpgradedEvent as TemplateBeingUpgradedEvent
from .TemplateUpgradeEvent import TemplateUpgradeEvent as TemplateUpgradeEvent
from .TemplateUpgradeFailedEvent import TemplateUpgradeFailedEvent as TemplateUpgradeFailedEvent
from .TemplateUpgradedEvent import TemplateUpgradedEvent as TemplateUpgradedEvent
from .TimedOutHostOperationEvent import TimedOutHostOperationEvent as TimedOutHostOperationEvent
from .UnlicensedVirtualMachinesEvent import UnlicensedVirtualMachinesEvent as UnlicensedVirtualMachinesEvent
from .UnlicensedVirtualMachinesFoundEvent import UnlicensedVirtualMachinesFoundEvent as UnlicensedVirtualMachinesFoundEvent
from .UpdatedAgentBeingRestartedEvent import UpdatedAgentBeingRestartedEvent as UpdatedAgentBeingRestartedEvent
from .UpgradeEvent import UpgradeEvent as UpgradeEvent
from .UplinkPortMtuNotSupportEvent import UplinkPortMtuNotSupportEvent as UplinkPortMtuNotSupportEvent
from .UplinkPortMtuSupportEvent import UplinkPortMtuSupportEvent as UplinkPortMtuSupportEvent
from .UplinkPortVlanTrunkedEvent import UplinkPortVlanTrunkedEvent as UplinkPortVlanTrunkedEvent
from .UplinkPortVlanUntrunkedEvent import UplinkPortVlanUntrunkedEvent as UplinkPortVlanUntrunkedEvent
from .UserAssignedToGroup import UserAssignedToGroup as UserAssignedToGroup
from .UserLoginSessionEvent import UserLoginSessionEvent as UserLoginSessionEvent
from .UserLogoutSessionEvent import UserLogoutSessionEvent as UserLogoutSessionEvent
from .UserPasswordChanged import UserPasswordChanged as UserPasswordChanged
from .UserUnassignedFromGroup import UserUnassignedFromGroup as UserUnassignedFromGroup
from .UserUpgradeEvent import UserUpgradeEvent as UserUpgradeEvent
from .VMFSDatastoreCreatedEvent import VMFSDatastoreCreatedEvent as VMFSDatastoreCreatedEvent
from .VMFSDatastoreExpandedEvent import VMFSDatastoreExpandedEvent as VMFSDatastoreExpandedEvent
from .VMFSDatastoreExtendedEvent import VMFSDatastoreExtendedEvent as VMFSDatastoreExtendedEvent
from .VMotionLicenseExpiredEvent import VMotionLicenseExpiredEvent as VMotionLicenseExpiredEvent
from .VcAgentUninstallFailedEvent import VcAgentUninstallFailedEvent as VcAgentUninstallFailedEvent
from .VcAgentUninstalledEvent import VcAgentUninstalledEvent as VcAgentUninstalledEvent
from .VcAgentUpgradeFailedEvent import VcAgentUpgradeFailedEvent as VcAgentUpgradeFailedEvent
from .VcAgentUpgradedEvent import VcAgentUpgradedEvent as VcAgentUpgradedEvent
from .VimAccountPasswordChangedEvent import VimAccountPasswordChangedEvent as VimAccountPasswordChangedEvent
from .VmAcquiredMksTicketEvent import VmAcquiredMksTicketEvent as VmAcquiredMksTicketEvent
from .VmAcquiredTicketEvent import VmAcquiredTicketEvent as VmAcquiredTicketEvent
from .VmAutoRenameEvent import VmAutoRenameEvent as VmAutoRenameEvent
from .VmBeingClonedEvent import VmBeingClonedEvent as VmBeingClonedEvent
from .VmBeingClonedNoFolderEvent import VmBeingClonedNoFolderEvent as VmBeingClonedNoFolderEvent
from .VmBeingCreatedEvent import VmBeingCreatedEvent as VmBeingCreatedEvent
from .VmBeingDeployedEvent import VmBeingDeployedEvent as VmBeingDeployedEvent
from .VmBeingHotMigratedEvent import VmBeingHotMigratedEvent as VmBeingHotMigratedEvent
from .VmBeingMigratedEvent import VmBeingMigratedEvent as VmBeingMigratedEvent
from .VmBeingRelocatedEvent import VmBeingRelocatedEvent as VmBeingRelocatedEvent
from .VmCloneEvent import VmCloneEvent as VmCloneEvent
from .VmCloneFailedEvent import VmCloneFailedEvent as VmCloneFailedEvent
from .VmClonedEvent import VmClonedEvent as VmClonedEvent
from .VmConfigMissingEvent import VmConfigMissingEvent as VmConfigMissingEvent
from .VmConnectedEvent import VmConnectedEvent as VmConnectedEvent
from .VmCreatedEvent import VmCreatedEvent as VmCreatedEvent
from .VmDasBeingResetEvent import VmDasBeingResetEvent as VmDasBeingResetEvent
from .VmDasBeingResetWithScreenshotEvent import VmDasBeingResetWithScreenshotEvent as VmDasBeingResetWithScreenshotEvent
from .VmDasResetFailedEvent import VmDasResetFailedEvent as VmDasResetFailedEvent
from .VmDasUpdateErrorEvent import VmDasUpdateErrorEvent as VmDasUpdateErrorEvent
from .VmDasUpdateOkEvent import VmDasUpdateOkEvent as VmDasUpdateOkEvent
from .VmDateRolledBackEvent import VmDateRolledBackEvent as VmDateRolledBackEvent
from .VmDeployFailedEvent import VmDeployFailedEvent as VmDeployFailedEvent
from .VmDeployedEvent import VmDeployedEvent as VmDeployedEvent
from .VmDisconnectedEvent import VmDisconnectedEvent as VmDisconnectedEvent
from .VmDiscoveredEvent import VmDiscoveredEvent as VmDiscoveredEvent
from .VmDiskFailedEvent import VmDiskFailedEvent as VmDiskFailedEvent
from .VmEmigratingEvent import VmEmigratingEvent as VmEmigratingEvent
from .VmEndRecordingEvent import VmEndRecordingEvent as VmEndRecordingEvent
from .VmEndReplayingEvent import VmEndReplayingEvent as VmEndReplayingEvent
from .VmEvent import VmEvent as VmEvent
from .VmEventArgument import VmEventArgument as VmEventArgument
from .VmFailedMigrateEvent import VmFailedMigrateEvent as VmFailedMigrateEvent
from .VmFailedRelayoutEvent import VmFailedRelayoutEvent as VmFailedRelayoutEvent
from .VmFailedRelayoutOnVmfs2DatastoreEvent import VmFailedRelayoutOnVmfs2DatastoreEvent as VmFailedRelayoutOnVmfs2DatastoreEvent
from .VmFailedStartingSecondaryEvent import VmFailedStartingSecondaryEvent as VmFailedStartingSecondaryEvent
from .VmFailedToPowerOffEvent import VmFailedToPowerOffEvent as VmFailedToPowerOffEvent
from .VmFailedToPowerOnEvent import VmFailedToPowerOnEvent as VmFailedToPowerOnEvent
from .VmFailedToRebootGuestEvent import VmFailedToRebootGuestEvent as VmFailedToRebootGuestEvent
from .VmFailedToResetEvent import VmFailedToResetEvent as VmFailedToResetEvent
from .VmFailedToShutdownGuestEvent import VmFailedToShutdownGuestEvent as VmFailedToShutdownGuestEvent
from .VmFailedToStandbyGuestEvent import VmFailedToStandbyGuestEvent as VmFailedToStandbyGuestEvent
from .VmFailedToSuspendEvent import VmFailedToSuspendEvent as VmFailedToSuspendEvent
from .VmFailedUpdatingSecondaryConfig import VmFailedUpdatingSecondaryConfig as VmFailedUpdatingSecondaryConfig
from .VmFailoverFailed import VmFailoverFailed as VmFailoverFailed
from .VmFaultToleranceStateChangedEvent import VmFaultToleranceStateChangedEvent as VmFaultToleranceStateChangedEvent
from .VmFaultToleranceTurnedOffEvent import VmFaultToleranceTurnedOffEvent as VmFaultToleranceTurnedOffEvent
from .VmFaultToleranceVmTerminatedEvent import VmFaultToleranceVmTerminatedEvent as VmFaultToleranceVmTerminatedEvent
from .VmGuestOSCrashedEvent import VmGuestOSCrashedEvent as VmGuestOSCrashedEvent
from .VmGuestRebootEvent import VmGuestRebootEvent as VmGuestRebootEvent
from .VmGuestShutdownEvent import VmGuestShutdownEvent as VmGuestShutdownEvent
from .VmGuestStandbyEvent import VmGuestStandbyEvent as VmGuestStandbyEvent
from .VmHealthMonitoringStateChangedEvent import VmHealthMonitoringStateChangedEvent as VmHealthMonitoringStateChangedEvent
from .VmInstanceUuidAssignedEvent import VmInstanceUuidAssignedEvent as VmInstanceUuidAssignedEvent
from .VmInstanceUuidChangedEvent import VmInstanceUuidChangedEvent as VmInstanceUuidChangedEvent
from .VmInstanceUuidConflictEvent import VmInstanceUuidConflictEvent as VmInstanceUuidConflictEvent
from .VmMacAssignedEvent import VmMacAssignedEvent as VmMacAssignedEvent
from .VmMacChangedEvent import VmMacChangedEvent as VmMacChangedEvent
from .VmMacConflictEvent import VmMacConflictEvent as VmMacConflictEvent
from .VmMaxFTRestartCountReached import VmMaxFTRestartCountReached as VmMaxFTRestartCountReached
from .VmMaxRestartCountReached import VmMaxRestartCountReached as VmMaxRestartCountReached
from .VmMessageErrorEvent import VmMessageErrorEvent as VmMessageErrorEvent
from .VmMessageEvent import VmMessageEvent as VmMessageEvent
from .VmMessageWarningEvent import VmMessageWarningEvent as VmMessageWarningEvent
from .VmMigratedEvent import VmMigratedEvent as VmMigratedEvent
from .VmNoCompatibleHostForSecondaryEvent import VmNoCompatibleHostForSecondaryEvent as VmNoCompatibleHostForSecondaryEvent
from .VmNoNetworkAccessEvent import VmNoNetworkAccessEvent as VmNoNetworkAccessEvent
from .VmOrphanedEvent import VmOrphanedEvent as VmOrphanedEvent
from .VmPowerOffOnIsolationEvent import VmPowerOffOnIsolationEvent as VmPowerOffOnIsolationEvent
from .VmPoweredOffEvent import VmPoweredOffEvent as VmPoweredOffEvent
from .VmPoweredOnEvent import VmPoweredOnEvent as VmPoweredOnEvent
from .VmPoweringOnWithCustomizedDVPortEvent import VmPoweringOnWithCustomizedDVPortEvent as VmPoweringOnWithCustomizedDVPortEvent
from .VmPrimaryFailoverEvent import VmPrimaryFailoverEvent as VmPrimaryFailoverEvent
from .VmReconfiguredEvent import VmReconfiguredEvent as VmReconfiguredEvent
from .VmRegisteredEvent import VmRegisteredEvent as VmRegisteredEvent
from .VmRelayoutSuccessfulEvent import VmRelayoutSuccessfulEvent as VmRelayoutSuccessfulEvent
from .VmRelayoutUpToDateEvent import VmRelayoutUpToDateEvent as VmRelayoutUpToDateEvent
from .VmReloadFromPathEvent import VmReloadFromPathEvent as VmReloadFromPathEvent
from .VmReloadFromPathFailedEvent import VmReloadFromPathFailedEvent as VmReloadFromPathFailedEvent
from .VmRelocateFailedEvent import VmRelocateFailedEvent as VmRelocateFailedEvent
from .VmRelocateSpecEvent import VmRelocateSpecEvent as VmRelocateSpecEvent
from .VmRelocatedEvent import VmRelocatedEvent as VmRelocatedEvent
from .VmRemoteConsoleConnectedEvent import VmRemoteConsoleConnectedEvent as VmRemoteConsoleConnectedEvent
from .VmRemoteConsoleDisconnectedEvent import VmRemoteConsoleDisconnectedEvent as VmRemoteConsoleDisconnectedEvent
from .VmRemovedEvent import VmRemovedEvent as VmRemovedEvent
from .VmRenamedEvent import VmRenamedEvent as VmRenamedEvent
from .VmRequirementsExceedCurrentEVCModeEvent import VmRequirementsExceedCurrentEVCModeEvent as VmRequirementsExceedCurrentEVCModeEvent
from .VmResettingEvent import VmResettingEvent as VmResettingEvent
from .VmResourcePoolMovedEvent import VmResourcePoolMovedEvent as VmResourcePoolMovedEvent
from .VmResourceReallocatedEvent import VmResourceReallocatedEvent as VmResourceReallocatedEvent
from .VmRestartedOnAlternateHostEvent import VmRestartedOnAlternateHostEvent as VmRestartedOnAlternateHostEvent
from .VmResumingEvent import VmResumingEvent as VmResumingEvent
from .VmSecondaryAddedEvent import VmSecondaryAddedEvent as VmSecondaryAddedEvent
from .VmSecondaryDisabledBySystemEvent import VmSecondaryDisabledBySystemEvent as VmSecondaryDisabledBySystemEvent
from .VmSecondaryDisabledEvent import VmSecondaryDisabledEvent as VmSecondaryDisabledEvent
from .VmSecondaryEnabledEvent import VmSecondaryEnabledEvent as VmSecondaryEnabledEvent
from .VmSecondaryStartedEvent import VmSecondaryStartedEvent as VmSecondaryStartedEvent
from .VmShutdownOnIsolationEvent import VmShutdownOnIsolationEvent as VmShutdownOnIsolationEvent
from .VmStartRecordingEvent import VmStartRecordingEvent as VmStartRecordingEvent
from .VmStartReplayingEvent import VmStartReplayingEvent as VmStartReplayingEvent
from .VmStartingEvent import VmStartingEvent as VmStartingEvent
from .VmStartingSecondaryEvent import VmStartingSecondaryEvent as VmStartingSecondaryEvent
from .VmStaticMacConflictEvent import VmStaticMacConflictEvent as VmStaticMacConflictEvent
from .VmStoppingEvent import VmStoppingEvent as VmStoppingEvent
from .VmSuspendedEvent import VmSuspendedEvent as VmSuspendedEvent
from .VmSuspendingEvent import VmSuspendingEvent as VmSuspendingEvent
from .VmTimedoutStartingSecondaryEvent import VmTimedoutStartingSecondaryEvent as VmTimedoutStartingSecondaryEvent
from .VmUnsupportedStartingEvent import VmUnsupportedStartingEvent as VmUnsupportedStartingEvent
from .VmUpgradeCompleteEvent import VmUpgradeCompleteEvent as VmUpgradeCompleteEvent
from .VmUpgradeFailedEvent import VmUpgradeFailedEvent as VmUpgradeFailedEvent
from .VmUpgradingEvent import VmUpgradingEvent as VmUpgradingEvent
from .VmUuidAssignedEvent import VmUuidAssignedEvent as VmUuidAssignedEvent
from .VmUuidChangedEvent import VmUuidChangedEvent as VmUuidChangedEvent
from .VmUuidConflictEvent import VmUuidConflictEvent as VmUuidConflictEvent
from .VmVnicPoolReservationViolationClearEvent import VmVnicPoolReservationViolationClearEvent as VmVnicPoolReservationViolationClearEvent
from .VmVnicPoolReservationViolationRaiseEvent import VmVnicPoolReservationViolationRaiseEvent as VmVnicPoolReservationViolationRaiseEvent
from .VmWwnAssignedEvent import VmWwnAssignedEvent as VmWwnAssignedEvent
from .VmWwnChangedEvent import VmWwnChangedEvent as VmWwnChangedEvent
from .VmWwnConflictEvent import VmWwnConflictEvent as VmWwnConflictEvent
from .VnicPortArgument import VnicPortArgument as VnicPortArgument
from .WarningUpgradeEvent import WarningUpgradeEvent as WarningUpgradeEvent
from .iScsiBootFailureEvent import iScsiBootFailureEvent as iScsiBootFailureEvent



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import PropertyPath

from pyVmomi.vim import ResourceConfigOption

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import IntOption
from pyVmomi.vim.option import LongOption

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualHardwareOption(DynamicData):
   hwVersion: int
   virtualDeviceOption: list[VirtualDeviceOption] = []
   deviceListReadonly: bool
   numCPU: list[int] = []
   numCoresPerSocket: IntOption
   autoCoresPerSocket: Optional[BoolOption] = None
   numCpuReadonly: bool
   memoryMB: LongOption
   numPCIControllers: IntOption
   numIDEControllers: IntOption
   numUSBControllers: IntOption
   numUSBXHCIControllers: IntOption
   numSIOControllers: IntOption
   numPS2Controllers: IntOption
   licensingLimit: list[PropertyPath] = []
   numSupportedWwnPorts: Optional[IntOption] = None
   numSupportedWwnNodes: Optional[IntOption] = None
   resourceConfigOption: ResourceConfigOption
   numNVDIMMControllers: Optional[IntOption] = None
   numTPMDevices: Optional[IntOption] = None
   numWDTDevices: Optional[IntOption] = None
   numPrecisionClockDevices: Optional[IntOption] = None
   epcMemoryMB: Optional[LongOption] = None
   acpiHostBridgesFirmware: list[str] = []
   numCpuSimultaneousThreads: Optional[IntOption] = None
   numNumaNodes: Optional[IntOption] = None
   numDeviceGroups: Optional[IntOption] = None
   deviceGroupTypes: list[type] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task

from pyVmomi.vim.cluster import VsanHostCreateVmHealthTestResult

from pyVmomi.vim.host import VsanEncryptionHealthSummary
from pyVmomi.vim.host import VsanFileServiceHealthSummary
from pyVmomi.vim.host import VsanHclFirmwareUpdateSpec
from pyVmomi.vim.host import VsanHealthQuerySpec
from pyVmomi.vim.host import VsanHostEMMSummary
from pyVmomi.vim.host import VsanHostHclInfo
from pyVmomi.vim.host import VsanHostQueryCheckLimitsSpec
from pyVmomi.vim.host import VsanIperfClientSpec
from pyVmomi.vim.host import VsanLimitHealthResult
from pyVmomi.vim.host import VsanNetworkDiagnosticsHealthInfo
from pyVmomi.vim.host import VsanNetworkHealthResult
from pyVmomi.vim.host import VsanNetworkLoadTestResult
from pyVmomi.vim.host import VsanObjectOverallHealth
from pyVmomi.vim.host import VsanPhysicalDiskHealthSummary
from pyVmomi.vim.host import VsanProactiveRebalanceInfoEx
from pyVmomi.vim.host import VsanQueryResultHostInfo
from pyVmomi.vim.host import VsanRepairObjectsResult
from pyVmomi.vim.host import VsanSmartStatsHostSummary
from pyVmomi.vim.host import VsanVmdkLoadTestResult
from pyVmomi.vim.host import VsanVmdkLoadTestSpec

from pyVmomi.vim.option import OptionValue

class VsanHealthSystem(ManagedObject):
   def QueryVerifyNetworkSettings(self, peers: list[str], ROBOStretchedClusterWitnesses: list[str], vMotionPeers: list[str], spec: Optional[VsanHealthQuerySpec]) -> VsanNetworkHealthResult: ...
   def QueryCheckLimits(self, spec: Optional[VsanHostQueryCheckLimitsSpec]) -> VsanLimitHealthResult: ...
   def QueryHostInfoByUuids(self, uuids: list[str]) -> list[VsanQueryResultHostInfo]: ...
   def QueryAdvCfg(self, options: list[str], includeAllAdvOptions: Optional[bool], nonDefaultOnly: Optional[bool]) -> list[OptionValue]: ...
   def QueryRunIperfServer(self, multicast: bool, serverIp: Optional[str], durationSec: Optional[int]) -> VsanNetworkLoadTestResult: ...
   def QueryRunIperfClient(self, multicast: bool, serverIp: str, durationSec: Optional[int], spec: Optional[VsanIperfClientSpec]) -> VsanNetworkLoadTestResult: ...
   def QueryObjectHealthSummary(self, objUuids: list[str], includeObjUuids: Optional[bool], localHostOnly: Optional[bool], includeNonComplianceObjDetail: Optional[bool], spec: Optional[VsanHealthQuerySpec]) -> VsanObjectOverallHealth: ...
   def QueryPhysicalDiskHealthSummary(self) -> VsanPhysicalDiskHealthSummary: ...
   def QueryEncryptionHealthSummary(self) -> VsanEncryptionHealthSummary: ...
   def QueryFileServiceHealthSummary(self) -> VsanFileServiceHealthSummary: ...
   def PrepareVmdkLoadTest(self, runname: str, specs: list[VsanVmdkLoadTestSpec]) -> str: ...
   def RunVmdkLoadTest(self, runname: str, durationSec: int, specs: list[VsanVmdkLoadTestSpec]) -> list[VsanVmdkLoadTestResult]: ...
   def CleanupVmdkLoadTest(self, runname: str, specs: list[VsanVmdkLoadTestSpec]) -> str: ...
   def QueryVersion(self, displayVersion: Optional[bool]) -> str: ...
   def CheckClomdLiveness(self) -> bool: ...
   def RepairImmediateObjects(self, uuids: list[str], repairType: Optional[str]) -> VsanRepairObjectsResult: ...
   def GetHclInfo(self, includeVendorInfo: Optional[bool], vsanEsaEligibleDisksOnly: Optional[bool]) -> VsanHostHclInfo: ...
   def StartProactiveRebalance(self, timeSpan: Optional[int], varianceThreshold: Optional[float], timeThreshold: Optional[int], rateThreshold: Optional[int]) -> bool: ...
   def StopProactiveRebalance(self) -> bool: ...
   def GetProactiveRebalanceInfo(self) -> VsanProactiveRebalanceInfoEx: ...
   def WaitForVsanHealthGenerationIdChange(self, timeout: int) -> bool: ...
   def FlashScsiControllerFirmware(self, spec: VsanHclFirmwareUpdateSpec) -> Task: ...
   def CreateVmHealthTest(self, timeout: int) -> VsanHostCreateVmHealthTestResult: ...
   def QuerySmartStats(self, disks: list[str], includeAllDisks: Optional[bool]) -> VsanSmartStatsHostSummary: ...
   def QueryHostEMMState(self) -> VsanHostEMMSummary: ...
   def GetNetworkDiagnosticsHealthInfo(self) -> VsanNetworkDiagnosticsHealthInfo: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import ChoiceOption
from pyVmomi.vim.option import LongOption

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualVMCIDeviceOption(VirtualDeviceOption):
   class FilterSpecOption(DynamicData):
      action: ChoiceOption
      protocol: ChoiceOption
      direction: ChoiceOption
      lowerDstPortBoundary: LongOption
      upperDstPortBoundary: LongOption

   allowUnrestrictedCommunication: BoolOption
   filterSpecOption: Optional[FilterSpecOption] = None
   filterSupported: Optional[BoolOption] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterNetworkPartitionInfo

from pyVmomi.vim.host import VsanNetworkHealthResult
from pyVmomi.vim.host import VsanQueryResultHostInfo

class VsanClusterNetworkHealthResult(DynamicData):
   hostResults: list[VsanNetworkHealthResult] = []
   issueFound: Optional[bool] = None
   vsanVmknicPresent: Optional[bool] = None
   matchingMulticastConfig: Optional[bool] = None
   matchingIpSubnets: Optional[bool] = None
   pingTestSuccess: Optional[bool] = None
   largePingTestSuccess: Optional[bool] = None
   hostLatencyCheckSuccess: Optional[bool] = None
   potentialMulticastIssue: Optional[bool] = None
   otherHostsInVsanCluster: list[str] = []
   partitions: list[VsanClusterNetworkPartitionInfo] = []
   hostsWithVsanDisabled: list[str] = []
   hostsDisconnected: list[str] = []
   hostsCommFailure: list[str] = []
   hostsInEsxMaintenanceMode: list[str] = []
   hostsInVsanMaintenanceMode: list[str] = []
   infoAboutUnexpectedHosts: list[VsanQueryResultHostInfo] = []
   clusterInUnicastMode: Optional[bool] = None
   clusterInRDMAMode: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.sms.storage import BackingConfig
from pyVmomi.sms.storage import FileSystemInfo

class StorageFileSystem(DynamicData):
   class FileSystemInterfaceVersion(Enum):
      NFSV3_0: ClassVar['FileSystemInterfaceVersion'] = 'NFSV3_0'

   uuid: str
   info: list[FileSystemInfo] = []
   nativeSnapshotSupported: bool
   thinProvisioningStatus: str
   type: str
   version: str
   backingConfig: Optional[BackingConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.pbm import ExtendedElementDescription
from pyVmomi.pbm import ServerObjectRef

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.pbm.compliance import OperationalStatus
from pyVmomi.pbm.compliance import PolicyStatus

from pyVmomi.pbm.profile import ProfileId

class ComplianceResult(DynamicData):
   class ComplianceStatus(Enum):
      compliant: ClassVar['ComplianceStatus'] = 'compliant'
      nonCompliant: ClassVar['ComplianceStatus'] = 'nonCompliant'
      unknown: ClassVar['ComplianceStatus'] = 'unknown'
      notApplicable: ClassVar['ComplianceStatus'] = 'notApplicable'
      outOfDate: ClassVar['ComplianceStatus'] = 'outOfDate'

   class ComplianceTaskStatus(Enum):
      inProgress: ClassVar['ComplianceTaskStatus'] = 'inProgress'
      success: ClassVar['ComplianceTaskStatus'] = 'success'
      failed: ClassVar['ComplianceTaskStatus'] = 'failed'

   checkTime: datetime
   entity: ServerObjectRef
   profile: Optional[ProfileId] = None
   complianceTaskStatus: Optional[str] = None
   complianceStatus: str
   mismatch: bool
   violatedPolicies: list[PolicyStatus] = []
   errorCause: list[MethodFault] = []
   operationalStatus: Optional[OperationalStatus] = None
   info: Optional[ExtendedElementDescription] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.vm import Summary
from pyVmomi.vim.vm import TargetInfo

class UsbInfo(TargetInfo):
   class Speed(Enum):
      low: ClassVar['Speed'] = 'low'
      full: ClassVar['Speed'] = 'full'
      high: ClassVar['Speed'] = 'high'
      superSpeed: ClassVar['Speed'] = 'superSpeed'
      superSpeedPlus: ClassVar['Speed'] = 'superSpeedPlus'
      superSpeed20Gbps: ClassVar['Speed'] = 'superSpeed20Gbps'
      unknownSpeed: ClassVar['Speed'] = 'unknownSpeed'

   class Family(Enum):
      audio: ClassVar['Family'] = 'audio'
      hid: ClassVar['Family'] = 'hid'
      hid_bootable: ClassVar['Family'] = 'hid_bootable'
      physical: ClassVar['Family'] = 'physical'
      communication: ClassVar['Family'] = 'communication'
      imaging: ClassVar['Family'] = 'imaging'
      printer: ClassVar['Family'] = 'printer'
      storage: ClassVar['Family'] = 'storage'
      hub: ClassVar['Family'] = 'hub'
      smart_card: ClassVar['Family'] = 'smart_card'
      security: ClassVar['Family'] = 'security'
      video: ClassVar['Family'] = 'video'
      wireless: ClassVar['Family'] = 'wireless'
      bluetooth: ClassVar['Family'] = 'bluetooth'
      wusb: ClassVar['Family'] = 'wusb'
      pda: ClassVar['Family'] = 'pda'
      vendor_specific: ClassVar['Family'] = 'vendor_specific'
      other: ClassVar['Family'] = 'other'
      unknownFamily: ClassVar['Family'] = 'unknownFamily'

   description: str
   vendor: int
   product: int
   physicalPath: str
   family: list[str] = []
   speed: list[str] = []
   summary: Optional[Summary] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import MethodFault

class ProviderOutOfProvisioningResource(MethodFault):
   provisioningResourceId: str
   availableBefore: Optional[long] = None
   availableAfter: Optional[long] = None
   total: Optional[long] = None
   isTransient: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import StoragePod

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import RuleInfo

from pyVmomi.vim.storageDrs import VmConfigInfo

from pyVmomi.vim.vm import ProfileSpec

from pyVmomi.vim.vm.device import VirtualDevice

class PodSelectionSpec(DynamicData):
   class VmPodConfig(DynamicData):
      storagePod: StoragePod
      disk: list[DiskLocator] = []
      vmConfig: Optional[VmConfigInfo] = None
      interVmRule: list[RuleInfo] = []

   class DiskLocator(DynamicData):
      diskId: int
      diskMoveType: Optional[str] = None
      diskBackingInfo: Optional[VirtualDevice.BackingInfo] = None
      profile: list[ProfileSpec] = []

   initialVmConfig: list[VmPodConfig] = []
   storagePod: Optional[StoragePod] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.vm.device import VirtualDiskId

class DrsFaults(DynamicData):
   class FaultsByVm(DynamicData):
      vm: Optional[VirtualMachine] = None
      fault: list[MethodFault] = []

   class FaultsByVirtualDisk(FaultsByVm):
      disk: Optional[VirtualDiskId] = None

   reason: str
   faultsByVm: list[FaultsByVm] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import LicenseManager

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue

class LicenseAssignmentManager(ManagedObject):
   class LicenseAssignment(DynamicData):
      entityId: str
      scope: Optional[str] = None
      entityDisplayName: Optional[str] = None
      assignedLicense: LicenseManager.LicenseInfo
      properties: list[KeyAnyValue] = []

   def UpdateAssignedLicense(self, entity: str, licenseKey: str, entityDisplayName: Optional[str]) -> LicenseManager.LicenseInfo: ...
   def RemoveAssignedLicense(self, entityId: str) -> NoReturn: ...
   def QueryAssignedLicenses(self, entityId: Optional[str]) -> list[LicenseAssignment]: ...



# VMware vSphere Python SDK tests
#
# Copyright (c) 2008-2025 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
import os
import unittest

from vcr import config
from vcr.stubs import VCRHTTPConnection, VCRHTTPSConnection

from pyVmomi import SoapAdapter
from pyVim import connect


def tests_resource_path(local_path=''):
    this_file = os.path.dirname(os.path.abspath(__file__))
    return os.path.join(this_file, local_path)

# Fully qualified path to the fixtures directory underneath this module
fixtures_path = tests_resource_path('fixtures')

class VCRTestBase(unittest.TestCase):
    my_vcr = config.VCR(
        custom_patches=(
            (SoapAdapter, 'HTTPConnection', VCRHTTPConnection),
            (SoapAdapter, 'HTTPSConnection', VCRHTTPSConnection),
            (connect, 'HTTPConnection', VCRHTTPConnection),
            (connect, 'HTTPSConnection', VCRHTTPSConnection),
        )
    )

    def setUp(self):
        logging.basicConfig()
        vcr_log = logging.getLogger('vcr')
        vcr_log.setLevel(logging.WARNING)



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualSerialPort(VirtualDevice):
   class FileBackingInfo(VirtualDevice.FileBackingInfo):
      pass

   class DeviceBackingInfo(VirtualDevice.DeviceBackingInfo):
      pass

   class PipeBackingInfo(VirtualDevice.PipeBackingInfo):
      endpoint: str
      noRxLoss: Optional[bool] = None

   class URIBackingInfo(VirtualDevice.URIBackingInfo):
      pass

   class ThinPrintBackingInfo(VirtualDevice.BackingInfo):
      pass

   yieldOnPoll: bool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanNetworkPeerHealthResult
from pyVmomi.vim.host import VsanServerClusterInfo

class VsanNetworkHealthResult(DynamicData):
   host: Optional[HostSystem] = None
   hostname: Optional[str] = None
   vsanVmknicPresent: Optional[bool] = None
   ipSubnets: list[str] = []
   issueFound: Optional[bool] = None
   peerHealth: list[VsanNetworkPeerHealthResult] = []
   vMotionHealth: list[VsanNetworkPeerHealthResult] = []
   multicastConfig: Optional[str] = None
   unicastConfig: Optional[str] = None
   inUnicast: Optional[bool] = None
   rdmaEnabled: Optional[bool] = None
   rdtConnProtocol: Optional[str] = None
   serverClusters: list[VsanServerClusterInfo] = []
   externalPeerHealth: list[VsanNetworkPeerHealthResult] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ComplianceResourceCheckStatusType import ComplianceResourceCheckStatusType as ComplianceResourceCheckStatusType
from .ConfigInfo import ConfigInfo as ConfigInfo
from .CoreConfigInfo import CoreConfigInfo as CoreConfigInfo
from .CoreConfigSpec import CoreConfigSpec as CoreConfigSpec
from .VsanManagedStorageType import VsanManagedStorageType as VsanManagedStorageType



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import Ruleset

class FirewallInfo(DynamicData):
   class DefaultPolicy(DynamicData):
      incomingBlocked: Optional[bool] = None
      outgoingBlocked: Optional[bool] = None

   defaultPolicy: DefaultPolicy
   ruleset: list[Ruleset] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import HostConnectFault

class AgentInstallFailed(HostConnectFault):
   class Reason(Enum):
      NotEnoughSpaceOnDevice: ClassVar['Reason'] = 'NotEnoughSpaceOnDevice'
      PrepareToUpgradeFailed: ClassVar['Reason'] = 'PrepareToUpgradeFailed'
      AgentNotRunning: ClassVar['Reason'] = 'AgentNotRunning'
      AgentNotReachable: ClassVar['Reason'] = 'AgentNotReachable'
      InstallTimedout: ClassVar['Reason'] = 'InstallTimedout'
      SignatureVerificationFailed: ClassVar['Reason'] = 'SignatureVerificationFailed'
      AgentUploadFailed: ClassVar['Reason'] = 'AgentUploadFailed'
      AgentUploadTimedout: ClassVar['Reason'] = 'AgentUploadTimedout'
      UnknownInstallerError: ClassVar['Reason'] = 'UnknownInstallerError'

   reason: Optional[str] = None
   statusCode: Optional[int] = None
   installerOutput: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import VirtualDiskManager

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanVmdkIOLoadSpec

class VsanVmdkLoadTestSpec(DynamicData):
   vmdkCreateSpec: Optional[VirtualDiskManager.FileBackedVirtualDiskSpec] = None
   vmdkIOSpec: Optional[VsanVmdkIOLoadSpec] = None
   vmdkIOSpecSequence: list[VsanVmdkIOLoadSpec] = []
   stepDurationSec: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import ChoiceOption
from pyVmomi.vim.option import IntOption

from pyVmomi.vim.vm.device import VirtualVmxnetOption

class VirtualVmxnet3Option(VirtualVmxnetOption):
   class StrictLatencyConfigOption(DynamicData):
      allowed: BoolOption
      measureLatency: BoolOption
      maxTxQueues: IntOption
      maxRxQueues: IntOption
      txDataRingDescSize: IntOption
      rxDataRingDescSize: IntOption
      disableOffload: ChoiceOption

   uptv2Enabled: Optional[BoolOption] = None
   strictLatencyConfigOption: Optional[StrictLatencyConfigOption] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ActiveDirectoryAuthentication import ActiveDirectoryAuthentication as ActiveDirectoryAuthentication
from .ActiveDirectoryInfo import ActiveDirectoryInfo as ActiveDirectoryInfo
from .ActiveDirectorySpec import ActiveDirectorySpec as ActiveDirectorySpec
from .AssignableHardwareBinding import AssignableHardwareBinding as AssignableHardwareBinding
from .AssignableHardwareConfig import AssignableHardwareConfig as AssignableHardwareConfig
from .AssignableHardwareManager import AssignableHardwareManager as AssignableHardwareManager
from .AuthenticationInfo import AuthenticationInfo as AuthenticationInfo
from .AuthenticationManager import AuthenticationManager as AuthenticationManager
from .AuthenticationManagerInfo import AuthenticationManagerInfo as AuthenticationManagerInfo
from .AuthenticationStore import AuthenticationStore as AuthenticationStore
from .AuthenticationStoreInfo import AuthenticationStoreInfo as AuthenticationStoreInfo
from .AutoStartManager import AutoStartManager as AutoStartManager
from .BIOSInfo import BIOSInfo as BIOSInfo
from .BlockAdapterTargetTransport import BlockAdapterTargetTransport as BlockAdapterTargetTransport
from .BlockHba import BlockHba as BlockHba
from .BootDeviceInfo import BootDeviceInfo as BootDeviceInfo
from .BootDeviceSystem import BootDeviceSystem as BootDeviceSystem
from .CacheConfigurationManager import CacheConfigurationManager as CacheConfigurationManager
from .Capability import Capability as Capability
from .CertificateManager import CertificateManager as CertificateManager
from .ConfigChange import ConfigChange as ConfigChange
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigManager import ConfigManager as ConfigManager
from .ConfigSpec import ConfigSpec as ConfigSpec
from .ConnectInfo import ConnectInfo as ConnectInfo
from .ConnectSpec import ConnectSpec as ConnectSpec
from .CpuIdInfo import CpuIdInfo as CpuIdInfo
from .CpuInfo import CpuInfo as CpuInfo
from .CpuPackage import CpuPackage as CpuPackage
from .CpuPowerManagementInfo import CpuPowerManagementInfo as CpuPowerManagementInfo
from .CpuSchedulerSystem import CpuSchedulerSystem as CpuSchedulerSystem
from .DataTransportConnectionInfo import DataTransportConnectionInfo as DataTransportConnectionInfo
from .DatastoreBrowser import DatastoreBrowser as DatastoreBrowser
from .DatastoreSystem import DatastoreSystem as DatastoreSystem
from .DateTimeConfig import DateTimeConfig as DateTimeConfig
from .DateTimeInfo import DateTimeInfo as DateTimeInfo
from .DateTimeSystem import DateTimeSystem as DateTimeSystem
from .DeploymentInfo import DeploymentInfo as DeploymentInfo
from .Device import Device as Device
from .DevicePciId import DevicePciId as DevicePciId
from .DhcpService import DhcpService as DhcpService
from .DiagnosticPartition import DiagnosticPartition as DiagnosticPartition
from .DiagnosticSystem import DiagnosticSystem as DiagnosticSystem
from .DigestInfo import DigestInfo as DigestInfo
from .DigestVerificationSetting import DigestVerificationSetting as DigestVerificationSetting
from .DirectoryStore import DirectoryStore as DirectoryStore
from .DirectoryStoreInfo import DirectoryStoreInfo as DirectoryStoreInfo
from .DiskConfigurationResult import DiskConfigurationResult as DiskConfigurationResult
from .DiskDimensions import DiskDimensions as DiskDimensions
from .DiskPartitionInfo import DiskPartitionInfo as DiskPartitionInfo
from .DnsConfig import DnsConfig as DnsConfig
from .DnsConfigSpec import DnsConfigSpec as DnsConfigSpec
from .DvxClass import DvxClass as DvxClass
from .EnterMaintenanceResult import EnterMaintenanceResult as EnterMaintenanceResult
from .EsxAgentHostManager import EsxAgentHostManager as EsxAgentHostManager
from .FcoeConfig import FcoeConfig as FcoeConfig
from .FeatureCapability import FeatureCapability as FeatureCapability
from .FeatureMask import FeatureMask as FeatureMask
from .FeatureVersionInfo import FeatureVersionInfo as FeatureVersionInfo
from .FibreChannelHba import FibreChannelHba as FibreChannelHba
from .FibreChannelOverEthernetHba import FibreChannelOverEthernetHba as FibreChannelOverEthernetHba
from .FibreChannelOverEthernetTargetTransport import FibreChannelOverEthernetTargetTransport as FibreChannelOverEthernetTargetTransport
from .FibreChannelTargetTransport import FibreChannelTargetTransport as FibreChannelTargetTransport
from .FileAccess import FileAccess as FileAccess
from .FileSystemMountInfo import FileSystemMountInfo as FileSystemMountInfo
from .FileSystemVolume import FileSystemVolume as FileSystemVolume
from .FileSystemVolumeInfo import FileSystemVolumeInfo as FileSystemVolumeInfo
from .FirewallConfig import FirewallConfig as FirewallConfig
from .FirewallInfo import FirewallInfo as FirewallInfo
from .FirewallSystem import FirewallSystem as FirewallSystem
from .FirmwareSystem import FirmwareSystem as FirmwareSystem
from .FlagInfo import FlagInfo as FlagInfo
from .ForceMountedInfo import ForceMountedInfo as ForceMountedInfo
from .Fru import Fru as Fru
from .GatewaySpec import GatewaySpec as GatewaySpec
from .GraphicsConfig import GraphicsConfig as GraphicsConfig
from .GraphicsInfo import GraphicsInfo as GraphicsInfo
from .GraphicsManager import GraphicsManager as GraphicsManager
from .HardwareInfo import HardwareInfo as HardwareInfo
from .HardwareStatusInfo import HardwareStatusInfo as HardwareStatusInfo
from .HbaCreateSpec import HbaCreateSpec as HbaCreateSpec
from .HealthStatusSystem import HealthStatusSystem as HealthStatusSystem
from .HostAccessManager import HostAccessManager as HostAccessManager
from .HostBusAdapter import HostBusAdapter as HostBusAdapter
from .HostProxySwitch import HostProxySwitch as HostProxySwitch
from .HostSpbm import HostSpbm as HostSpbm
from .HostSpbmDatastoreInfo import HostSpbmDatastoreInfo as HostSpbmDatastoreInfo
from .HostSpbmHashInfo import HostSpbmHashInfo as HostSpbmHashInfo
from .HostSpbmPolicyBlobInfo import HostSpbmPolicyBlobInfo as HostSpbmPolicyBlobInfo
from .HostSpbmPolicyInfo import HostSpbmPolicyInfo as HostSpbmPolicyInfo
from .ImageConfigManager import ImageConfigManager as ImageConfigManager
from .InternetScsiHba import InternetScsiHba as InternetScsiHba
from .InternetScsiTargetTransport import InternetScsiTargetTransport as InternetScsiTargetTransport
from .IpConfig import IpConfig as IpConfig
from .IpRouteConfig import IpRouteConfig as IpRouteConfig
from .IpRouteConfigSpec import IpRouteConfigSpec as IpRouteConfigSpec
from .IpRouteEntry import IpRouteEntry as IpRouteEntry
from .IpRouteOp import IpRouteOp as IpRouteOp
from .IpRouteTableConfig import IpRouteTableConfig as IpRouteTableConfig
from .IpRouteTableInfo import IpRouteTableInfo as IpRouteTableInfo
from .IpmiInfo import IpmiInfo as IpmiInfo
from .IscsiManager import IscsiManager as IscsiManager
from .KernelModuleSystem import KernelModuleSystem as KernelModuleSystem
from .LACPInfo import LACPInfo as LACPInfo
from .LAGInfo import LAGInfo as LAGInfo
from .LAGUplinkInfo import LAGUplinkInfo as LAGUplinkInfo
from .LicenseSpec import LicenseSpec as LicenseSpec
from .LinkDiscoveryProtocolConfig import LinkDiscoveryProtocolConfig as LinkDiscoveryProtocolConfig
from .LocalAccountManager import LocalAccountManager as LocalAccountManager
from .LocalAuthentication import LocalAuthentication as LocalAuthentication
from .LocalAuthenticationInfo import LocalAuthenticationInfo as LocalAuthenticationInfo
from .LocalDatastoreInfo import LocalDatastoreInfo as LocalDatastoreInfo
from .LocalFileSystemVolume import LocalFileSystemVolume as LocalFileSystemVolume
from .MaintenanceSpec import MaintenanceSpec as MaintenanceSpec
from .MemoryManagerSystem import MemoryManagerSystem as MemoryManagerSystem
from .MemorySpec import MemorySpec as MemorySpec
from .MemoryTierFlags import MemoryTierFlags as MemoryTierFlags
from .MemoryTierInfo import MemoryTierInfo as MemoryTierInfo
from .MemoryTierType import MemoryTierType as MemoryTierType
from .MemoryTieringType import MemoryTieringType as MemoryTieringType
from .MessageBusProxy import MessageBusProxy as MessageBusProxy
from .MountInfo import MountInfo as MountInfo
from .MultipathInfo import MultipathInfo as MultipathInfo
from .MultipathStateInfo import MultipathStateInfo as MultipathStateInfo
from .NasDatastoreInfo import NasDatastoreInfo as NasDatastoreInfo
from .NasVolume import NasVolume as NasVolume
from .NatService import NatService as NatService
from .NetCapabilities import NetCapabilities as NetCapabilities
from .NetOffloadCapabilities import NetOffloadCapabilities as NetOffloadCapabilities
from .NetStackInstance import NetStackInstance as NetStackInstance
from .NetworkConfig import NetworkConfig as NetworkConfig
from .NetworkInfo import NetworkInfo as NetworkInfo
from .NetworkPolicy import NetworkPolicy as NetworkPolicy
from .NetworkSystem import NetworkSystem as NetworkSystem
from .NfcConnectionInfo import NfcConnectionInfo as NfcConnectionInfo
from .NtpConfig import NtpConfig as NtpConfig
from .NumaInfo import NumaInfo as NumaInfo
from .NumaNode import NumaNode as NumaNode
from .NumericSensorInfo import NumericSensorInfo as NumericSensorInfo
from .NvdimmSystem import NvdimmSystem as NvdimmSystem
from .NvmeConnectSpec import NvmeConnectSpec as NvmeConnectSpec
from .NvmeController import NvmeController as NvmeController
from .NvmeDisconnectSpec import NvmeDisconnectSpec as NvmeDisconnectSpec
from .NvmeDiscoverSpec import NvmeDiscoverSpec as NvmeDiscoverSpec
from .NvmeDiscoveryLog import NvmeDiscoveryLog as NvmeDiscoveryLog
from .NvmeNamespace import NvmeNamespace as NvmeNamespace
from .NvmeOpaqueTransportParameters import NvmeOpaqueTransportParameters as NvmeOpaqueTransportParameters
from .NvmeOverFibreChannelParameters import NvmeOverFibreChannelParameters as NvmeOverFibreChannelParameters
from .NvmeOverRdmaParameters import NvmeOverRdmaParameters as NvmeOverRdmaParameters
from .NvmeOverTcpParameters import NvmeOverTcpParameters as NvmeOverTcpParameters
from .NvmeSpec import NvmeSpec as NvmeSpec
from .NvmeTopology import NvmeTopology as NvmeTopology
from .NvmeTransportParameters import NvmeTransportParameters as NvmeTransportParameters
from .NvmeTransportType import NvmeTransportType as NvmeTransportType
from .OpaqueNetworkInfo import OpaqueNetworkInfo as OpaqueNetworkInfo
from .OpaqueSwitch import OpaqueSwitch as OpaqueSwitch
from .PMemDatastoreInfo import PMemDatastoreInfo as PMemDatastoreInfo
from .PMemVolume import PMemVolume as PMemVolume
from .ParallelScsiHba import ParallelScsiHba as ParallelScsiHba
from .ParallelScsiTargetTransport import ParallelScsiTargetTransport as ParallelScsiTargetTransport
from .PartialMaintenanceModeId import PartialMaintenanceModeId as PartialMaintenanceModeId
from .PartialMaintenanceModeRuntimeInfo import PartialMaintenanceModeRuntimeInfo as PartialMaintenanceModeRuntimeInfo
from .PartialMaintenanceModeStatus import PartialMaintenanceModeStatus as PartialMaintenanceModeStatus
from .PatchManager import PatchManager as PatchManager
from .PathSelectionPolicyOption import PathSelectionPolicyOption as PathSelectionPolicyOption
from .PciDevice import PciDevice as PciDevice
from .PciPassthruConfig import PciPassthruConfig as PciPassthruConfig
from .PciPassthruInfo import PciPassthruInfo as PciPassthruInfo
from .PciPassthruSystem import PciPassthruSystem as PciPassthruSystem
from .PcieHba import PcieHba as PcieHba
from .PcieTargetTransport import PcieTargetTransport as PcieTargetTransport
from .PersistentMemoryInfo import PersistentMemoryInfo as PersistentMemoryInfo
from .PhysicalNic import PhysicalNic as PhysicalNic
from .PlugStoreTopology import PlugStoreTopology as PlugStoreTopology
from .PnicTSOInfo import PnicTSOInfo as PnicTSOInfo
from .PortGroup import PortGroup as PortGroup
from .PowerSystem import PowerSystem as PowerSystem
from .ProtocolEndpoint import ProtocolEndpoint as ProtocolEndpoint
from .PtpConfig import PtpConfig as PtpConfig
from .QualifiedName import QualifiedName as QualifiedName
from .RdmaDevice import RdmaDevice as RdmaDevice
from .RdmaHba import RdmaHba as RdmaHba
from .RdmaProtocol import RdmaProtocol as RdmaProtocol
from .RdmaTargetTransport import RdmaTargetTransport as RdmaTargetTransport
from .ReliableMemoryInfo import ReliableMemoryInfo as ReliableMemoryInfo
from .ResignatureRescanResult import ResignatureRescanResult as ResignatureRescanResult
from .Ruleset import Ruleset as Ruleset
from .RuntimeInfo import RuntimeInfo as RuntimeInfo
from .ScsiDisk import ScsiDisk as ScsiDisk
from .ScsiLun import ScsiLun as ScsiLun
from .ScsiTopology import ScsiTopology as ScsiTopology
from .SecuritySpec import SecuritySpec as SecuritySpec
from .SerialAttachedHba import SerialAttachedHba as SerialAttachedHba
from .SerialAttachedTargetTransport import SerialAttachedTargetTransport as SerialAttachedTargetTransport
from .Service import Service as Service
from .ServiceConfig import ServiceConfig as ServiceConfig
from .ServiceInfo import ServiceInfo as ServiceInfo
from .ServiceSystem import ServiceSystem as ServiceSystem
from .SevInfo import SevInfo as SevInfo
from .SgxInfo import SgxInfo as SgxInfo
from .SgxRegistrationInfo import SgxRegistrationInfo as SgxRegistrationInfo
from .SharedGpuCapabilities import SharedGpuCapabilities as SharedGpuCapabilities
from .SnmpSystem import SnmpSystem as SnmpSystem
from .SoftwarePackage import SoftwarePackage as SoftwarePackage
from .SriovConfig import SriovConfig as SriovConfig
from .SriovDevicePoolInfo import SriovDevicePoolInfo as SriovDevicePoolInfo
from .SriovInfo import SriovInfo as SriovInfo
from .SriovNetworkDevicePoolInfo import SriovNetworkDevicePoolInfo as SriovNetworkDevicePoolInfo
from .SslThumbprintInfo import SslThumbprintInfo as SslThumbprintInfo
from .StorageArrayTypePolicyOption import StorageArrayTypePolicyOption as StorageArrayTypePolicyOption
from .StorageDeviceInfo import StorageDeviceInfo as StorageDeviceInfo
from .StorageProtocol import StorageProtocol as StorageProtocol
from .StorageSystem import StorageSystem as StorageSystem
from .Summary import Summary as Summary
from .SystemEventInfo import SystemEventInfo as SystemEventInfo
from .SystemHealthInfo import SystemHealthInfo as SystemHealthInfo
from .SystemIdentificationInfo import SystemIdentificationInfo as SystemIdentificationInfo
from .SystemInfo import SystemInfo as SystemInfo
from .SystemResourceInfo import SystemResourceInfo as SystemResourceInfo
from .SystemSwapConfiguration import SystemSwapConfiguration as SystemSwapConfiguration
from .TargetTransport import TargetTransport as TargetTransport
from .TcpHba import TcpHba as TcpHba
from .TcpHbaCreateSpec import TcpHbaCreateSpec as TcpHbaCreateSpec
from .TcpTargetTransport import TcpTargetTransport as TcpTargetTransport
from .TdxInfo import TdxInfo as TdxInfo
from .TpmAttestationInfo import TpmAttestationInfo as TpmAttestationInfo
from .TpmAttestationReport import TpmAttestationReport as TpmAttestationReport
from .TpmBootCompleteEventDetails import TpmBootCompleteEventDetails as TpmBootCompleteEventDetails
from .TpmBootSecurityOptionEventDetails import TpmBootSecurityOptionEventDetails as TpmBootSecurityOptionEventDetails
from .TpmCommandEventDetails import TpmCommandEventDetails as TpmCommandEventDetails
from .TpmDigestInfo import TpmDigestInfo as TpmDigestInfo
from .TpmEventDetails import TpmEventDetails as TpmEventDetails
from .TpmEventLogEntry import TpmEventLogEntry as TpmEventLogEntry
from .TpmNvTagEventDetails import TpmNvTagEventDetails as TpmNvTagEventDetails
from .TpmOptionEventDetails import TpmOptionEventDetails as TpmOptionEventDetails
from .TpmSignerEventDetails import TpmSignerEventDetails as TpmSignerEventDetails
from .TpmSoftwareComponentEventDetails import TpmSoftwareComponentEventDetails as TpmSoftwareComponentEventDetails
from .TpmVersionEventDetails import TpmVersionEventDetails as TpmVersionEventDetails
from .TrustAuthorityAttestationInfo import TrustAuthorityAttestationInfo as TrustAuthorityAttestationInfo
from .UnresolvedVmfsExtent import UnresolvedVmfsExtent as UnresolvedVmfsExtent
from .UnresolvedVmfsResignatureSpec import UnresolvedVmfsResignatureSpec as UnresolvedVmfsResignatureSpec
from .UnresolvedVmfsResolutionResult import UnresolvedVmfsResolutionResult as UnresolvedVmfsResolutionResult
from .UnresolvedVmfsResolutionSpec import UnresolvedVmfsResolutionSpec as UnresolvedVmfsResolutionSpec
from .UnresolvedVmfsVolume import UnresolvedVmfsVolume as UnresolvedVmfsVolume
from .VFlashManager import VFlashManager as VFlashManager
from .VFlashResourceConfigurationResult import VFlashResourceConfigurationResult as VFlashResourceConfigurationResult
from .VMotionConfig import VMotionConfig as VMotionConfig
from .VMotionInfo import VMotionInfo as VMotionInfo
from .VMotionSystem import VMotionSystem as VMotionSystem
from .VSANStretchedClusterHostCapability import VSANStretchedClusterHostCapability as VSANStretchedClusterHostCapability
from .VfatVolume import VfatVolume as VfatVolume
from .VffsVolume import VffsVolume as VffsVolume
from .VirtualNic import VirtualNic as VirtualNic
from .VirtualNicConnection import VirtualNicConnection as VirtualNicConnection
from .VirtualNicManager import VirtualNicManager as VirtualNicManager
from .VirtualNicManagerInfo import VirtualNicManagerInfo as VirtualNicManagerInfo
from .VirtualSwitch import VirtualSwitch as VirtualSwitch
from .VmfsDatastoreCreateSpec import VmfsDatastoreCreateSpec as VmfsDatastoreCreateSpec
from .VmfsDatastoreExpandSpec import VmfsDatastoreExpandSpec as VmfsDatastoreExpandSpec
from .VmfsDatastoreExtendSpec import VmfsDatastoreExtendSpec as VmfsDatastoreExtendSpec
from .VmfsDatastoreInfo import VmfsDatastoreInfo as VmfsDatastoreInfo
from .VmfsDatastoreOption import VmfsDatastoreOption as VmfsDatastoreOption
from .VmfsDatastoreSpec import VmfsDatastoreSpec as VmfsDatastoreSpec
from .VmfsRescanResult import VmfsRescanResult as VmfsRescanResult
from .VmfsVolume import VmfsVolume as VmfsVolume
from .VsanBasicDeviceInfo import VsanBasicDeviceInfo as VsanBasicDeviceInfo
from .VsanClusterMembershipInfo import VsanClusterMembershipInfo as VsanClusterMembershipInfo
from .VsanControllerType import VsanControllerType as VsanControllerType
from .VsanDaemonHealth import VsanDaemonHealth as VsanDaemonHealth
from .VsanDatastoreInfo import VsanDatastoreInfo as VsanDatastoreInfo
from .VsanDiskBalanceState import VsanDiskBalanceState as VsanDiskBalanceState
from .VsanDiskEncryptionHealth import VsanDiskEncryptionHealth as VsanDiskEncryptionHealth
from .VsanDiskRebalanceResult import VsanDiskRebalanceResult as VsanDiskRebalanceResult
from .VsanDitEncryptionHealthSummary import VsanDitEncryptionHealthSummary as VsanDitEncryptionHealthSummary
from .VsanEncryptionHealthSummary import VsanEncryptionHealthSummary as VsanEncryptionHealthSummary
from .VsanEncryptionIssue import VsanEncryptionIssue as VsanEncryptionIssue
from .VsanFailedRepairObjectResult import VsanFailedRepairObjectResult as VsanFailedRepairObjectResult
from .VsanFileServerHealthSummary import VsanFileServerHealthSummary as VsanFileServerHealthSummary
from .VsanFileServiceBalanceHealth import VsanFileServiceBalanceHealth as VsanFileServiceBalanceHealth
from .VsanFileServiceHealthSummary import VsanFileServiceHealthSummary as VsanFileServiceHealthSummary
from .VsanFileServiceRootFsHealth import VsanFileServiceRootFsHealth as VsanFileServiceRootFsHealth
from .VsanFileServiceShareHealthSummary import VsanFileServiceShareHealthSummary as VsanFileServiceShareHealthSummary
from .VsanHclCommonDeviceInfo import VsanHclCommonDeviceInfo as VsanHclCommonDeviceInfo
from .VsanHclComputeResource import VsanHclComputeResource as VsanHclComputeResource
from .VsanHclControllerInfo import VsanHclControllerInfo as VsanHclControllerInfo
from .VsanHclDiskInfo import VsanHclDiskInfo as VsanHclDiskInfo
from .VsanHclFirmwareFile import VsanHclFirmwareFile as VsanHclFirmwareFile
from .VsanHclFirmwareUpdateSpec import VsanHclFirmwareUpdateSpec as VsanHclFirmwareUpdateSpec
from .VsanHclMemInfo import VsanHclMemInfo as VsanHclMemInfo
from .VsanHclNicInfo import VsanHclNicInfo as VsanHclNicInfo
from .VsanHealthQuerySpec import VsanHealthQuerySpec as VsanHealthQuerySpec
from .VsanHealthSystem import VsanHealthSystem as VsanHealthSystem
from .VsanHostCimProviderInfo import VsanHostCimProviderInfo as VsanHostCimProviderInfo
from .VsanHostEMMSummary import VsanHostEMMSummary as VsanHostEMMSummary
from .VsanHostFwComponent import VsanHostFwComponent as VsanHostFwComponent
from .VsanHostGlobalDedupConfigHealthSummary import VsanHostGlobalDedupConfigHealthSummary as VsanHostGlobalDedupConfigHealthSummary
from .VsanHostHclInfo import VsanHostHclInfo as VsanHostHclInfo
from .VsanHostHealthSystemStatusResult import VsanHostHealthSystemStatusResult as VsanHostHealthSystemStatusResult
from .VsanHostHwDeviceId import VsanHostHwDeviceId as VsanHostHwDeviceId
from .VsanHostIoInsightInfo import VsanHostIoInsightInfo as VsanHostIoInsightInfo
from .VsanHostQueryCheckLimitsOptionType import VsanHostQueryCheckLimitsOptionType as VsanHostQueryCheckLimitsOptionType
from .VsanHostQueryCheckLimitsSpec import VsanHostQueryCheckLimitsSpec as VsanHostQueryCheckLimitsSpec
from .VsanHostReference import VsanHostReference as VsanHostReference
from .VsanHostVirtualApplianceInfo import VsanHostVirtualApplianceInfo as VsanHostVirtualApplianceInfo
from .VsanHostVmdkLoadTestResult import VsanHostVmdkLoadTestResult as VsanHostVmdkLoadTestResult
from .VsanHwToVcgInfoMapping import VsanHwToVcgInfoMapping as VsanHwToVcgInfoMapping
from .VsanInternalSystem import VsanInternalSystem as VsanInternalSystem
from .VsanIoInsightInfo import VsanIoInsightInfo as VsanIoInsightInfo
from .VsanIoInsightState import VsanIoInsightState as VsanIoInsightState
from .VsanIperfClientSpec import VsanIperfClientSpec as VsanIperfClientSpec
from .VsanKmsHealth import VsanKmsHealth as VsanKmsHealth
from .VsanLimitHealthResult import VsanLimitHealthResult as VsanLimitHealthResult
from .VsanNetworkDiagnosticsHealthInfo import VsanNetworkDiagnosticsHealthInfo as VsanNetworkDiagnosticsHealthInfo
from .VsanNetworkHealthResult import VsanNetworkHealthResult as VsanNetworkHealthResult
from .VsanNetworkLoadTestResult import VsanNetworkLoadTestResult as VsanNetworkLoadTestResult
from .VsanNetworkPeerHealthResult import VsanNetworkPeerHealthResult as VsanNetworkPeerHealthResult
from .VsanNicRdmaInfo import VsanNicRdmaInfo as VsanNicRdmaInfo
from .VsanObjectHealth import VsanObjectHealth as VsanObjectHealth
from .VsanObjectOverallHealth import VsanObjectOverallHealth as VsanObjectOverallHealth
from .VsanPeerHostConnectivityHealthState import VsanPeerHostConnectivityHealthState as VsanPeerHostConnectivityHealthState
from .VsanPhysicalDiskHealth import VsanPhysicalDiskHealth as VsanPhysicalDiskHealth
from .VsanPhysicalDiskHealthSummary import VsanPhysicalDiskHealthSummary as VsanPhysicalDiskHealthSummary
from .VsanProactiveRebalanceInfoEx import VsanProactiveRebalanceInfoEx as VsanProactiveRebalanceInfoEx
from .VsanQueryResultHostInfo import VsanQueryResultHostInfo as VsanQueryResultHostInfo
from .VsanRepairObjectsResult import VsanRepairObjectsResult as VsanRepairObjectsResult
from .VsanResourceHealth import VsanResourceHealth as VsanResourceHealth
from .VsanServerClusterInfo import VsanServerClusterInfo as VsanServerClusterInfo
from .VsanSmartDiskStats import VsanSmartDiskStats as VsanSmartDiskStats
from .VsanSmartParameter import VsanSmartParameter as VsanSmartParameter
from .VsanSmartParameterType import VsanSmartParameterType as VsanSmartParameterType
from .VsanSmartStatsHostSummary import VsanSmartStatsHostSummary as VsanSmartStatsHostSummary
from .VsanSystem import VsanSystem as VsanSystem
from .VsanSystemEx import VsanSystemEx as VsanSystemEx
from .VsanUpdateManager import VsanUpdateManager as VsanUpdateManager
from .VsanVcgDeviceInfo import VsanVcgDeviceInfo as VsanVcgDeviceInfo
from .VsanVcsaDeployerSystem import VsanVcsaDeployerSystem as VsanVcsaDeployerSystem
from .VsanVmdkIOLoadSpec import VsanVmdkIOLoadSpec as VsanVmdkIOLoadSpec
from .VsanVmdkLoadTestResult import VsanVmdkLoadTestResult as VsanVmdkLoadTestResult
from .VsanVmdkLoadTestSpec import VsanVmdkLoadTestSpec as VsanVmdkLoadTestSpec
from .VsanVsanPcapResult import VsanVsanPcapResult as VsanVsanPcapResult
from .VvolDatastoreInfo import VvolDatastoreInfo as VvolDatastoreInfo
from .VvolNQN import VvolNQN as VvolNQN
from .VvolVolume import VvolVolume as VvolVolume



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.host import IpConfig

class FileServiceIpConfig(IpConfig):
   fqdn: Optional[str] = None
   isPrimary: Optional[bool] = None
   gateway: str
   affinityLocation: Optional[str] = None
   ipv6Gateway: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.vm import GuestQuiesceSpec

class WindowsQuiesceSpec(GuestQuiesceSpec):
   class VssBackupContext(Enum):
      ctx_auto: ClassVar['VssBackupContext'] = 'ctx_auto'
      ctx_backup: ClassVar['VssBackupContext'] = 'ctx_backup'
      ctx_file_share_backup: ClassVar['VssBackupContext'] = 'ctx_file_share_backup'

   vssBackupType: Optional[int] = None
   vssBootableSystemState: Optional[bool] = None
   vssPartialFileSupport: Optional[bool] = None
   vssBackupContext: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.option import BoolOption

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualCdromOption(VirtualDeviceOption):
   class IsoBackingOption(VirtualDeviceOption.FileBackingOption):
      pass

   class PassthroughBackingOption(VirtualDeviceOption.DeviceBackingOption):
      exclusive: BoolOption

   class RemotePassthroughBackingOption(VirtualDeviceOption.RemoteDeviceBackingOption):
      exclusive: BoolOption

   class AtapiBackingOption(VirtualDeviceOption.DeviceBackingOption):
      pass

   class RemoteAtapiBackingOption(VirtualDeviceOption.DeviceBackingOption):
      pass



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.vim.cluster import VsanAttachToSrOperation
from pyVmomi.vim.cluster import VsanClusterCreateVmHealthTestResult
from pyVmomi.vim.cluster import VsanClusterFileServiceHealthSummary
from pyVmomi.vim.cluster import VsanClusterHclInfo
from pyVmomi.vim.cluster import VsanClusterHealthCheckInfo
from pyVmomi.vim.cluster import VsanClusterHealthConfigs
from pyVmomi.vim.cluster import VsanClusterHealthQuerySpec
from pyVmomi.vim.cluster import VsanClusterHealthSummary
from pyVmomi.vim.cluster import VsanClusterHealthSystemVersionResult
from pyVmomi.vim.cluster import VsanClusterNetworkLoadTestResult
from pyVmomi.vim.cluster import VsanClusterNetworkPerfTaskSpec
from pyVmomi.vim.cluster import VsanClusterTelemetryProxyConfig
from pyVmomi.vim.cluster import VsanClusterVmdkLoadTestResult
from pyVmomi.vim.cluster import VsanHistoricalHealthQuerySpec
from pyVmomi.vim.cluster import VsanObjectExtAttrs
from pyVmomi.vim.cluster import VsanStorageWorkloadType

from pyVmomi.vim.host import VsanSmartStatsHostSummary
from pyVmomi.vim.host import VsanVmdkLoadTestSpec

from pyVmomi.vim.vsan import VsanDiskModelInfo
from pyVmomi.vim.vsan import VsanHclDiskConstraint
from pyVmomi.vim.vsan import VsanHclQuerySpec
from pyVmomi.vim.vsan import VsanHclReleaseConstraint
from pyVmomi.vim.vsan import VsanHwToVcgInfoMappingSpec

class VsanVcClusterHealthSystem(ManagedObject):
   class VsanHealthLogLevelEnum(Enum):
      INFO: ClassVar['VsanHealthLogLevelEnum'] = 'INFO'
      WARNING: ClassVar['VsanHealthLogLevelEnum'] = 'WARNING'
      ERROR: ClassVar['VsanHealthLogLevelEnum'] = 'ERROR'
      DEBUG: ClassVar['VsanHealthLogLevelEnum'] = 'DEBUG'
      CRITICAL: ClassVar['VsanHealthLogLevelEnum'] = 'CRITICAL'
      VsanHealthLogLevelEnum_Unknown: ClassVar['VsanHealthLogLevelEnum'] = 'VsanHealthLogLevelEnum_Unknown'

   def QueryVerifyClusterHealthSystemVersions(self, cluster: ClusterComputeResource) -> VsanClusterHealthSystemVersionResult: ...
   def QueryFileServiceHealthSummary(self, cluster: ClusterComputeResource, includeFileServerHealth: Optional[bool], includeFileShareHealth: Optional[bool]) -> Optional[VsanClusterFileServiceHealthSummary]: ...
   def QueryClusterCreateVmHealthTest(self, cluster: ClusterComputeResource, timeout: int, datastore: Optional[Datastore]) -> VsanClusterCreateVmHealthTestResult: ...
   def QueryClusterHealthSummary(self, cluster: Optional[ClusterComputeResource], vmCreateTimeout: Optional[int], objUuids: list[str], includeObjUuids: Optional[bool], fields: list[str], fetchFromCache: Optional[bool], perspective: Optional[str], hosts: list[HostSystem], spec: Optional[VsanClusterHealthQuerySpec]) -> VsanClusterHealthSummary: ...
   def QueryClusterHealthSummaryTask(self, cluster: ClusterComputeResource, hosts: list[HostSystem], includeDataProtectionHealth: Optional[bool], includeOnlineHealth: Optional[bool]) -> Task: ...
   def QueryVsanObjExtAttrs(self, cluster: ClusterComputeResource, uuids: list[str]) -> list[VsanObjectExtAttrs]: ...
   def QueryAllSupportedHealthChecks(self) -> list[VsanClusterHealthCheckInfo]: ...
   def QueryClusterNetworkPerfTest(self, cluster: ClusterComputeResource, multicast: bool, durationSec: Optional[int]) -> VsanClusterNetworkLoadTestResult: ...
   def QueryClusterNetworkPerfTask(self, cluster: ClusterComputeResource, spec: Optional[VsanClusterNetworkPerfTaskSpec]) -> Task: ...
   def RunVmdkLoadTest(self, cluster: ClusterComputeResource, runname: str, durationSec: Optional[int], specs: list[VsanVmdkLoadTestSpec], action: Optional[str]) -> Task: ...
   def QueryVsanClusterHealthConfig(self, cluster: ClusterComputeResource) -> VsanClusterHealthConfigs: ...
   def QueryVsanClusterHealthCheckInterval(self, cluster: ClusterComputeResource) -> int: ...
   def SetVsanClusterHealthCheckInterval(self, cluster: ClusterComputeResource, vsanClusterHealthCheckInterval: int) -> NoReturn: ...
   def GetVsanClusterSilentChecks(self, cluster: ClusterComputeResource) -> list[str]: ...
   def SetVsanClusterSilentChecks(self, cluster: ClusterComputeResource, addSilentChecks: list[str], removeSilentChecks: list[str]) -> bool: ...
   def SetVsanClusterTelemetryConfig(self, cluster: ClusterComputeResource, vsanClusterHealthConfig: VsanClusterHealthConfigs) -> NoReturn: ...
   def TestVsanClusterTelemetryProxy(self, proxyConfig: VsanClusterTelemetryProxyConfig) -> bool: ...
   def SendVsanTelemetry(self, cluster: ClusterComputeResource) -> NoReturn: ...
   def RepairClusterObjectsImmediate(self, cluster: ClusterComputeResource, uuids: list[str]) -> Task: ...
   def UpdateDefaultDSPolicyRecommendation(self, cluster: ClusterComputeResource) -> Task: ...
   def QueryClusterCreateVmHealthHistoryTest(self, cluster: ClusterComputeResource, count: Optional[int], datastore: Optional[Datastore]) -> list[VsanClusterCreateVmHealthTestResult]: ...
   def QueryClusterNetworkPerfHistoryTest(self, cluster: ClusterComputeResource, count: Optional[int], spec: Optional[VsanClusterNetworkPerfTaskSpec]) -> list[VsanClusterNetworkLoadTestResult]: ...
   def QueryClusterVmdkLoadHistoryTest(self, cluster: ClusterComputeResource, count: Optional[int], taskId: Optional[str]) -> list[VsanClusterVmdkLoadTestResult]: ...
   def QueryClusterVmdkWorkloadTypes(self) -> list[VsanStorageWorkloadType]: ...
   def QueryAttachToSrHistory(self, cluster: ClusterComputeResource, count: Optional[int], taskId: Optional[str]) -> list[VsanAttachToSrOperation]: ...
   def AttachVsanSupportBundleToSr(self, cluster: ClusterComputeResource, srNumber: str) -> Task: ...
   def GetClusterHclInfo(self, cluster: Optional[ClusterComputeResource], includeHostsResult: Optional[bool], includeVendorInfo: Optional[bool], esxRelease: Optional[str], querySpec: Optional[VsanHclQuerySpec]) -> VsanClusterHclInfo: ...
   def GetHclInfoForVsanEligibleDisks(self, querySpec: VsanHclQuerySpec) -> VsanClusterHclInfo: ...
   def DownloadHclFile(self, sha1sums: list[str]) -> Task: ...
   def GetClusterHclConstraints(self, cluster: ClusterComputeResource, release: str) -> VsanHclReleaseConstraint: ...
   def GetDiskHclConstraints(self, release: Optional[str], diskModels: list[VsanDiskModelInfo]) -> list[VsanHclDiskConstraint]: ...
   def GetClusterReleaseRecommendation(self, cluster: ClusterComputeResource, minor: list[str], major: list[str]) -> list[VsanHclReleaseConstraint]: ...
   def PurgeHclFiles(self, sha1sums: list[str]) -> NoReturn: ...
   def DownloadAndInstallVendorTool(self, cluster: ClusterComputeResource) -> Task: ...
   def UploadHclDb(self, db: str) -> bool: ...
   def UpdateHclDbFromWeb(self, url: Optional[str]) -> bool: ...
   def RebalanceCluster(self, cluster: ClusterComputeResource, targetHosts: list[HostSystem]) -> Task: ...
   def StopRebalanceCluster(self, cluster: ClusterComputeResource, targetHosts: list[HostSystem]) -> Task: ...
   def IsRebalanceRunning(self, cluster: ClusterComputeResource, targetHosts: list[HostSystem]) -> bool: ...
   def SetLogLevel(self, level: Optional[str]) -> NoReturn: ...
   def QuerySmartStatsSummary(self, cluster: ClusterComputeResource) -> list[VsanSmartStatsHostSummary]: ...
   def QueryVsanProxyConfig(self) -> VsanClusterTelemetryProxyConfig: ...
   def QueryClusterHistoricalHealth(self, spec: VsanHistoricalHealthQuerySpec) -> list[VsanClusterHealthSummary]: ...
   def SetVsanVcgMappingForHwDevices(self, spec: VsanHwToVcgInfoMappingSpec) -> bool: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoKeyId
from pyVmomi.vim.encryption import CryptoKeyPlain
from pyVmomi.vim.encryption import CryptoManager

class CryptoManagerHost(CryptoManager):
   class KeyManagementType(Enum):
      unknown: ClassVar['KeyManagementType'] = 'unknown'
      internal: ClassVar['KeyManagementType'] = 'internal'
      external: ClassVar['KeyManagementType'] = 'external'

   class KeyStatus(DynamicData):
      keyId: CryptoKeyId
      present: bool
      managementType: Optional[str] = None
      accessGranted: Optional[bool] = None

   def Prepare(self) -> NoReturn: ...
   def Enable(self, initialKey: CryptoKeyPlain) -> NoReturn: ...
   def ChangeKey(self, newKey: CryptoKeyPlain) -> Task: ...
   def Disable(self) -> NoReturn: ...
   def GetCryptoKeyStatus(self, keys: list[CryptoKeyId]) -> list[KeyStatus]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanObjectInformation
from pyVmomi.vim.cluster import VsanPerfNodeInformation

class VsanPerfsvcHealthResult(DynamicData):
   statsObjectInfo: Optional[VsanObjectInformation] = None
   statsObjectConsistent: Optional[bool] = None
   statsObjectPolicyConsistent: Optional[bool] = None
   datastoreCompatible: Optional[bool] = None
   enoughFreeSpace: Optional[bool] = None
   remediateAction: Optional[str] = None
   hostResults: list[VsanPerfNodeInformation] = []
   verboseModeStatus: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class Action(DynamicData):
   class ActionParameter(Enum):
      targetName: ClassVar['ActionParameter'] = 'targetName'
      alarmName: ClassVar['ActionParameter'] = 'alarmName'
      oldStatus: ClassVar['ActionParameter'] = 'oldStatus'
      newStatus: ClassVar['ActionParameter'] = 'newStatus'
      triggeringSummary: ClassVar['ActionParameter'] = 'triggeringSummary'
      declaringSummary: ClassVar['ActionParameter'] = 'declaringSummary'
      eventDescription: ClassVar['ActionParameter'] = 'eventDescription'
      target: ClassVar['ActionParameter'] = 'target'
      alarm: ClassVar['ActionParameter'] = 'alarm'



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim.cluster import VsanClusterAdvCfgSyncResult
from pyVmomi.vim.cluster import VsanClusterClomdLivenessResult
from pyVmomi.vim.cluster import VsanClusterCreateVmHealthTestResult
from pyVmomi.vim.cluster import VsanClusterHclInfo
from pyVmomi.vim.cluster import VsanClusterHealthSystemObjectsRepairResult
from pyVmomi.vim.cluster import VsanClusterHealthSystemVersionResult
from pyVmomi.vim.cluster import VsanClusterHostVmknicMapping
from pyVmomi.vim.cluster import VsanClusterLimitHealthResult
from pyVmomi.vim.cluster import VsanClusterNetworkHealthResult
from pyVmomi.vim.cluster import VsanClusterNetworkLoadTestResult
from pyVmomi.vim.cluster import VsanVsanClusterPcapResult

from pyVmomi.vim.host import VsanPhysicalDiskHealthSummary

class VsanClusterHealthSystem(ManagedObject):
   def QueryVerifyClusterNetworkSettings(self, hosts: list[str], esxRootPassword: str) -> VsanClusterNetworkHealthResult: ...
   def QueryCheckLimits(self, hosts: list[str], esxRootPassword: str) -> VsanClusterLimitHealthResult: ...
   def QueryPhysicalDiskHealthSummary(self, hosts: list[str], esxRootPassword: str) -> list[VsanPhysicalDiskHealthSummary]: ...
   def QueryAdvCfgSync(self, hosts: list[str], esxRootPassword: str, options: list[str]) -> list[VsanClusterAdvCfgSyncResult]: ...
   def QueryClusterCreateVmHealthTest(self, hosts: list[str], esxRootPassword: str, timeout: int) -> VsanClusterCreateVmHealthTestResult: ...
   def QueryClusterNetworkPerfTest(self, hosts: list[str], esxRootPassword: str, multicast: bool, durationSec: Optional[int]) -> VsanClusterNetworkLoadTestResult: ...
   def QueryCaptureVsanPcap(self, hosts: list[str], esxRootPassword: str, duration: int, vmknic: list[VsanClusterHostVmknicMapping], includeRawPcap: Optional[bool], includeIgmp: Optional[bool], cmmdsMsgTypeFilter: list[str], cmmdsPorts: list[int], clusterUuid: Optional[str]) -> VsanVsanClusterPcapResult: ...
   def QueryClusterHealthSystemVersions(self, hosts: list[str], esxRootPassword: str) -> VsanClusterHealthSystemVersionResult: ...
   def CheckClusterClomdLiveness(self, hosts: list[str], esxRootPassword: str) -> VsanClusterClomdLivenessResult: ...
   def RepairClusterImmediateObjects(self, hosts: list[str], esxRootPassword: str, uuids: list[str]) -> VsanClusterHealthSystemObjectsRepairResult: ...
   def GetClusterHclInfo(self, hosts: list[str], esxRootPassword: str) -> VsanClusterHclInfo: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .VmomiSupport import CreateDataType, CreateManagedType
from .VmomiSupport import CreateEnumType
from .VmomiSupport import AddVersion, AddVersionParent
from .VmomiSupport import AddBreakingChangesInfo
from .VmomiSupport import F_LINK, F_LINKABLE
from .VmomiSupport import F_OPTIONAL, F_SECRET

AddVersion("vmodl.version.version0", "", "", 0, "vim25")
AddVersion("vmodl.version.version1", "", "", 0, "vim25")
AddVersion("vmodl.version.version2", "", "", 0, "vim25")
AddVersionParent("vmodl.version.version0", "vmodl.version.version0")
AddVersionParent("vmodl.version.version1", "vmodl.version.version0")
AddVersionParent("vmodl.version.version1", "vmodl.version.version1")
AddVersionParent("vmodl.version.version2", "vmodl.version.version0")
AddVersionParent("vmodl.version.version2", "vmodl.version.version1")
AddVersionParent("vmodl.version.version2", "vmodl.version.version2")

from .VmomiSupport import newestVersions
newestVersions.Add("vmodl.version.version2")

from .VmomiSupport import ltsVersions
ltsVersions.Add("vmodl.version.version2")

from .VmomiSupport import oldestVersions
oldestVersions.Add("vmodl.version.version0")

CreateDataType("vmodl.DynamicArray", "DynamicArray", "vmodl.DataObject", "vmodl.version.version0", [("dynamicType", "string", "vmodl.version.version0", F_OPTIONAL), ("val", "anyType[]", "vmodl.version.version0", 0)])
CreateDataType("vmodl.DynamicData", "DynamicData", "vmodl.DataObject", "vmodl.version.version0", [("dynamicType", "string", "vmodl.version.version0", F_OPTIONAL), ("dynamicProperty", "vmodl.DynamicProperty[]", "vmodl.version.version0", F_OPTIONAL)])
CreateDataType("vmodl.DynamicProperty", "DynamicProperty", "vmodl.DataObject", "vmodl.version.version0", [("name", "vmodl.PropertyPath", "vmodl.version.version0", 0), ("val", "anyType", "vmodl.version.version0", 0)])
CreateDataType("vmodl.KeyAnyValue", "KeyAnyValue", "vmodl.DynamicData", "vmodl.version.version1", [("key", "string", "vmodl.version.version1", 0), ("value", "anyType", "vmodl.version.version1", 0)])
CreateDataType("vmodl.LocalizableMessage", "LocalizableMessage", "vmodl.DynamicData", "vmodl.version.version1", [("key", "string", "vmodl.version.version1", 0), ("arg", "vmodl.KeyAnyValue[]", "vmodl.version.version1", F_OPTIONAL), ("message", "string", "vmodl.version.version1", F_OPTIONAL)])
CreateDataType("vmodl.fault.HostCommunication", "HostCommunication", "vmodl.RuntimeFault", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.HostNotConnected", "HostNotConnected", "vmodl.fault.HostCommunication", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.HostNotReachable", "HostNotReachable", "vmodl.fault.HostCommunication", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.InvalidArgument", "InvalidArgument", "vmodl.RuntimeFault", "vmodl.version.version0", [("invalidProperty", "vmodl.PropertyPath", "vmodl.version.version0", F_OPTIONAL)])
CreateDataType("vmodl.fault.InvalidRequest", "InvalidRequest", "vmodl.RuntimeFault", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.InvalidType", "InvalidType", "vmodl.fault.InvalidRequest", "vmodl.version.version0", [("argument", "vmodl.PropertyPath", "vmodl.version.version0", F_OPTIONAL)])
CreateDataType("vmodl.fault.ManagedObjectNotFound", "ManagedObjectNotFound", "vmodl.RuntimeFault", "vmodl.version.version0", [("obj", "vmodl.ManagedObject", "vmodl.version.version0", 0)])
CreateDataType("vmodl.fault.MethodNotFound", "MethodNotFound", "vmodl.fault.InvalidRequest", "vmodl.version.version0", [("receiver", "vmodl.ManagedObject", "vmodl.version.version0", 0), ("method", "string", "vmodl.version.version0", 0)])
CreateDataType("vmodl.fault.NotEnoughLicenses", "NotEnoughLicenses", "vmodl.RuntimeFault", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.NotImplemented", "NotImplemented", "vmodl.RuntimeFault", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.NotSupported", "NotSupported", "vmodl.RuntimeFault", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.RequestCanceled", "RequestCanceled", "vmodl.RuntimeFault", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.SecurityError", "SecurityError", "vmodl.RuntimeFault", "vmodl.version.version0", None)
CreateDataType("vmodl.fault.SystemError", "SystemError", "vmodl.RuntimeFault", "vmodl.version.version0", [("reason", "string", "vmodl.version.version0", 0)])
CreateDataType("vmodl.fault.UnexpectedFault", "UnexpectedFault", "vmodl.RuntimeFault", "vmodl.version.version0", [("faultName", "vmodl.TypeName", "vmodl.version.version0", 0), ("fault", "vmodl.MethodFault", "vmodl.version.version0", F_OPTIONAL)])



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import KeyValue
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

class VsanObjectIdentity(DynamicData):
   uuid: str
   type: str
   vmInstanceUuid: Optional[str] = None
   vmNsObjectUuid: Optional[str] = None
   vm: Optional[VirtualMachine] = None
   description: Optional[str] = None
   spbmProfileUuid: Optional[str] = None
   metadatas: list[KeyValue] = []
   typeExtId: Optional[str] = None
   spbmProfileName: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import FileShareQueryProperties

class FileShareQuerySpec(DynamicData):
   domainName: Optional[str] = None
   uuids: list[str] = []
   names: list[str] = []
   offset: Optional[str] = None
   limit: Optional[long] = None
   managedBy: list[str] = []
   protocols: list[str] = []
   pageNumber: Optional[long] = None
   properties: Optional[FileShareQueryProperties] = None



# VMware vSphere Python SDK tests
#
# Copyright (c) 2017-2024 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import tests

from pyVim import connect
from pyVmomi import vim


class SoapAdapterTests(tests.VCRTestBase):
    def test_invoke_method_login_session_exception(self):
        def login_fail(*args, **kwargs):
            raise vim_session.SESSION_EXCEPTIONS[0]()

        stub = connect.SoapStubAdapter()
        vim_session = connect.VimSessionOrientedStub(stub, login_fail)
        self.assertRaises(vim.fault.NotAuthenticated, vim_session.InvokeAccessor, "mo", "info")



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import FirewallInfo
from pyVmomi.vim.host import Ruleset

class FirewallConfig(DynamicData):
   class RuleSetConfig(DynamicData):
      rulesetId: str
      enabled: bool
      allowedHosts: Optional[Ruleset.IpList] = None

   rule: list[RuleSetConfig] = []
   defaultBlockingPolicy: FirewallInfo.DefaultPolicy



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .Action import Action as Action
from .CreateTaskAction import CreateTaskAction as CreateTaskAction
from .MethodAction import MethodAction as MethodAction
from .MethodActionArgument import MethodActionArgument as MethodActionArgument
from .RunScriptAction import RunScriptAction as RunScriptAction
from .SendEmailAction import SendEmailAction as SendEmailAction
from .SendSNMPAction import SendSNMPAction as SendSNMPAction



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class VsanSyncingObjectRecoveryDetails(DynamicData):
   activelySyncingObjectRecoveryETA: Optional[long] = None
   queuedForSyncObjectRecoveryETA: Optional[long] = None
   suspendedObjectRecoveryETA: Optional[long] = None
   activeObjectsToSync: Optional[long] = None
   queuedObjectsToSync: Optional[long] = None
   suspendedObjectsToSync: Optional[long] = None
   bytesToSyncForActiveObjects: Optional[long] = None
   bytesToSyncForQueuedObjects: Optional[long] = None
   bytesToSyncForSuspendedObjects: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import AboutInfo
from pyVmomi.vim import AuthorizationManager
from pyVmomi.vim import CertificateManager
from pyVmomi.vim import CustomFieldsManager
from pyVmomi.vim import CustomizationSpecManager
from pyVmomi.vim import DatastoreNamespaceManager
from pyVmomi.vim import DiagnosticManager
from pyVmomi.vim import DirectPathProfileManager
from pyVmomi.vim import ExtensionManager
from pyVmomi.vim import FileManager
from pyVmomi.vim import Folder
from pyVmomi.vim import HealthUpdateManager
from pyVmomi.vim import IoFilterManager
from pyVmomi.vim import IpPoolManager
from pyVmomi.vim import LicenseManager
from pyVmomi.vim import LocalizationManager
from pyVmomi.vim import OverheadMemoryManager
from pyVmomi.vim import OvfManager
from pyVmomi.vim import PerformanceManager
from pyVmomi.vim import SearchIndex
from pyVmomi.vim import ServiceManager
from pyVmomi.vim import SessionManager
from pyVmomi.vim import SiteInfoManager
from pyVmomi.vim import StorageQueryManager
from pyVmomi.vim import StorageResourceManager
from pyVmomi.vim import TaskManager
from pyVmomi.vim import UserDirectory
from pyVmomi.vim import VirtualDiskManager
from pyVmomi.vim import VirtualizationManager

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.alarm import AlarmManager

from pyVmomi.vim.dvs import DistributedVirtualSwitchManager

from pyVmomi.vim.encryption import CryptoManager

from pyVmomi.vim.event import EventManager

from pyVmomi.vim.host import LocalAccountManager
from pyVmomi.vim.host import SnmpSystem

from pyVmomi.vim.option import OptionManager

from pyVmomi.vim.profile import ComplianceManager

from pyVmomi.vim.scheduler import ScheduledTaskManager

from pyVmomi.vim.tenant import TenantManager

from pyVmomi.vim.vcha import FailoverClusterConfigurator
from pyVmomi.vim.vcha import FailoverClusterManager

from pyVmomi.vim.view import ViewManager

from pyVmomi.vim.vm import GuestCustomizationManager

from pyVmomi.vim.vslm import VStorageObjectManagerBase

from pyVmomi.vmodl.query import PropertyCollector

from pyVmomi.vim.profile.cluster import ProfileManager

from pyVmomi.vim.profile.host import HostSpecificationManager
from pyVmomi.vim.profile.host import ProfileManager

from pyVmomi.vim.vm.check import CompatibilityChecker
from pyVmomi.vim.vm.check import ProvisioningChecker

from pyVmomi.vim.vm.guest import GuestOperationsManager

class ServiceInstanceContent(DynamicData):
   rootFolder: Folder
   propertyCollector: PropertyCollector
   viewManager: Optional[ViewManager] = None
   about: AboutInfo
   setting: Optional[OptionManager] = None
   userDirectory: Optional[UserDirectory] = None
   sessionManager: Optional[SessionManager] = None
   authorizationManager: Optional[AuthorizationManager] = None
   serviceManager: Optional[ServiceManager] = None
   perfManager: Optional[PerformanceManager] = None
   scheduledTaskManager: Optional[ScheduledTaskManager] = None
   alarmManager: Optional[AlarmManager] = None
   eventManager: Optional[EventManager] = None
   taskManager: Optional[TaskManager] = None
   extensionManager: Optional[ExtensionManager] = None
   customizationSpecManager: Optional[CustomizationSpecManager] = None
   guestCustomizationManager: Optional[GuestCustomizationManager] = None
   customFieldsManager: Optional[CustomFieldsManager] = None
   accountManager: Optional[LocalAccountManager] = None
   diagnosticManager: Optional[DiagnosticManager] = None
   licenseManager: Optional[LicenseManager] = None
   searchIndex: Optional[SearchIndex] = None
   fileManager: Optional[FileManager] = None
   datastoreNamespaceManager: Optional[DatastoreNamespaceManager] = None
   virtualDiskManager: Optional[VirtualDiskManager] = None
   virtualizationManager: Optional[VirtualizationManager] = None
   snmpSystem: Optional[SnmpSystem] = None
   vmProvisioningChecker: Optional[ProvisioningChecker] = None
   vmCompatibilityChecker: Optional[CompatibilityChecker] = None
   ovfManager: Optional[OvfManager] = None
   ipPoolManager: Optional[IpPoolManager] = None
   dvSwitchManager: Optional[DistributedVirtualSwitchManager] = None
   hostProfileManager: Optional[ProfileManager] = None
   clusterProfileManager: Optional[ProfileManager] = None
   complianceManager: Optional[ComplianceManager] = None
   localizationManager: Optional[LocalizationManager] = None
   storageResourceManager: Optional[StorageResourceManager] = None
   guestOperationsManager: Optional[GuestOperationsManager] = None
   overheadMemoryManager: Optional[OverheadMemoryManager] = None
   certificateManager: Optional[CertificateManager] = None
   ioFilterManager: Optional[IoFilterManager] = None
   vStorageObjectManager: Optional[VStorageObjectManagerBase] = None
   hostSpecManager: Optional[HostSpecificationManager] = None
   cryptoManager: Optional[CryptoManager] = None
   healthUpdateManager: Optional[HealthUpdateManager] = None
   failoverClusterConfigurator: Optional[FailoverClusterConfigurator] = None
   failoverClusterManager: Optional[FailoverClusterManager] = None
   tenantManager: Optional[TenantManager] = None
   siteInfoManager: Optional[SiteInfoManager] = None
   storageQueryManager: Optional[StorageQueryManager] = None
   directPathProfileManager: Optional[DirectPathProfileManager] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl.fault import InvalidArgument

class InvalidDasConfigArgument(InvalidArgument):
   class EntryForInvalidArgument(Enum):
      admissionControl: ClassVar['EntryForInvalidArgument'] = 'admissionControl'
      userHeartbeatDs: ClassVar['EntryForInvalidArgument'] = 'userHeartbeatDs'
      vmConfig: ClassVar['EntryForInvalidArgument'] = 'vmConfig'

   entry: Optional[str] = None
   clusterName: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class VsanHclDiskInfo(DynamicData):
   deviceName: str
   model: Optional[str] = None
   isSsd: Optional[bool] = None
   vsanDisk: bool
   issues: list[MethodFault] = []
   remediableIssues: list[str] = []
   uuid: Optional[str] = None
   capacity: Optional[long] = None
   vsanCompatibility: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.event import HostEvent

class HostDasErrorEvent(HostEvent):
   class HostDasErrorReason(Enum):
      configFailed: ClassVar['HostDasErrorReason'] = 'configFailed'
      timeout: ClassVar['HostDasErrorReason'] = 'timeout'
      communicationInitFailed: ClassVar['HostDasErrorReason'] = 'communicationInitFailed'
      healthCheckScriptFailed: ClassVar['HostDasErrorReason'] = 'healthCheckScriptFailed'
      agentFailed: ClassVar['HostDasErrorReason'] = 'agentFailed'
      agentShutdown: ClassVar['HostDasErrorReason'] = 'agentShutdown'
      isolationAddressUnpingable: ClassVar['HostDasErrorReason'] = 'isolationAddressUnpingable'
      other: ClassVar['HostDasErrorReason'] = 'other'

   message: Optional[str] = None
   reason: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanHclFirmwareFile
from pyVmomi.vim.host import VsanHostFwComponent

class VsanHclFirmwareUpdateSpec(DynamicData):
   host: HostSystem
   hbaDevice: str
   fwFiles: list[VsanHclFirmwareFile] = []
   allowDowngrade: Optional[bool] = None
   firmwareComponent: list[VsanHostFwComponent] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import ReplicationFault

class IncompatibleHostForVmReplication(ReplicationFault):
   class IncompatibleReason(Enum):
      rpo: ClassVar['IncompatibleReason'] = 'rpo'
      netCompression: ClassVar['IncompatibleReason'] = 'netCompression'

   vmName: str
   hostName: str
   reason: str
